@@ -1,9 +1,9 @@
-;;; cd-tool.el --- Play  CDs from Emacs
-;;;$Id: cd-tool.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; cd-tool.el --- Play  CDs from Emacs  -*- lexical-binding: t; -*-
+;;;$Id$
 ;;;Emacs front-end to CDTool
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -33,14 +33,14 @@
 ;;;   sunsite.unc.edu /pub/Linux/apps/sound/cdrom/cli
 ;;; This module also provides the ability to play or save
 ;;; clips from a CD if you have cdda2wav installed.
-;;; cdda2wav is a cd to wav convertor.
+;;; cdda2wav is a cd to wav converter.
 ;;;
 ;;; Code:
 ;;}}}
 ;;{{{ required packages
 
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 
 ;;}}}
 ;;{{{ top level
@@ -82,7 +82,7 @@ cap C   Save clip to disk
   (let ((command nil))
     (while (null command)
       (setq command
-            (case (read-char "CD Action? ")
+            (cl-case (read-char "CD Action? ")
               (?+ (concat cd-tool-start-command " +"))
               (?> (concat cd-tool-start-command " +"))
               (?. (concat cd-tool-start-command " +"))
@@ -105,7 +105,7 @@ cap C   Save clip to disk
                          nil))))
     (shell-command
      (format "%s &"
-             command ))))
+             command))))
 
 (defvar cd-tool-clipper "cdda2wav"
   "Program that can clip CD audio.")
@@ -124,10 +124,8 @@ cap C   Save clip to disk
 
 (defun cd-tool-get-clip-command (&optional save)
   "Query for and return an appropriate CD clip command"
-  (declare (special cd-tool-clipper
-                    cd-tool-clip-track-history
-                    cd-tool-clip-skip-history
-                    cd-tool-clip-duration-history))
+  (cl-declare (special cd-tool-clipper cd-tool-clip-track-history
+                       cd-tool-clip-skip-history cd-tool-clip-duration-history))
   (let ((filename (when save
                     (read-file-name
                      "File name to save clip to: ")))
@@ -139,18 +137,18 @@ cap C   Save clip to disk
                                     nil ; READ
                                     cd-tool-clip-track-history))
         (skip (read-from-minibuffer"Skip sectors: "
-                                   (car cd-tool-clip-skip-history ) ;INITIAL-CONTENTS
+                                   (car cd-tool-clip-skip-history) ;INITIAL-CONTENTS
                                    nil  ;KEYMAP
                                    nil  ; READ
                                    cd-tool-clip-skip-history))
         (duration  (read-from-minibuffer"Duration: "
-                                        (car cd-tool-clip-duration-history ) ;INITIAL-CONTENTS
+                                        (car cd-tool-clip-duration-history) ;INITIAL-CONTENTS
                                         nil ;KEYMAP
                                         nil ; READ
                                         cd-tool-clip-duration-history)))
-    (pushnew track cd-tool-clip-track-history)
-    (pushnew  skip cd-tool-clip-skip-history)
-    (pushnew duration cd-tool-clip-duration-history)
+    (cl-pushnew track cd-tool-clip-track-history :test #'string=)
+    (cl-pushnew  skip cd-tool-clip-skip-history :test #'string=)
+    (cl-pushnew duration cd-tool-clip-duration-history :test #'string=)
     (format "%s %s -t %s -o %s -d %s %s"
             cd-tool-clipper
             cd-tool-clipper-default-args
