@@ -1,5 +1,5 @@
-;;; emacspeak-add-log.el --- Speech-enable add-log
-;;; $Id: emacspeak-add-log.el 7286 2011-10-16 21:23:18Z tv.raman.tv $
+;;; emacspeak-add-log.el --- Speech-enable add-log  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  speech-enable change-log-mode
 ;;; Keywords: Emacspeak,  Audio Desktop ChangeLogs
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -47,9 +47,9 @@
 ;;}}}
 ;;{{{  Required modules
 
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
+(require 'cl-lib)
 (require 'custom)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ define personalities
@@ -60,14 +60,15 @@
 
 (voice-setup-add-map
  '(
-   (change-log-acknowledgement voice-smoothen)
+   (change-log-acknowledgment voice-smoothen)
    (change-log-conditionals voice-animate)
-   (change-log-email voice-womanize-1)
+   (change-log-email voice-lighten)
    (change-log-function voice-bolden-extra)
    (change-log-file voice-bolden)
-   (change-log-email voice-womanize-1)
+   (change-log-email voice-lighten)
    (change-log-list voice-lighten)
    (change-log-name voice-lighten-extra)
+   (change-log-date voice-monotone)
    ))
 
 ;;}}}
