@@ -1,4 +1,4 @@
-;;; emacspeak-amark.el --- BookMarks For Audio Content
+;;; emacspeak-amark.el --- BookMarks For Audio Content  -*- lexical-binding: t; -*-
 ;;; $Id: acss-structure.el 5798 2008-08-22 17:35:01Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Bookmarks for audio content like mp3
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2018, T. V. Raman 
 ;;; Copyright (c) 1996 by T. V. Raman
 ;;; All Rights Reserved.
 ;;;
@@ -48,19 +48,17 @@
 ;;; Position: time offset from start 
 
 ;;;; This library will be used from emacspeak-m-player,
-;;emacspeak-alsaplayer and friends to set and jump to bookmarks.
-
+;;emacspeak-mplayer and friends to set and jump to bookmarks.
+;;; Code:
 ;;}}}
 ;;{{{  Required modules
-
-;;; Code:
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
-
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
+(require 'emacspeak-sounds)
 ;;}}}
 ;;{{{ Structure:
 
-(defstruct emacspeak-amark
+(cl-defstruct emacspeak-amark
   path                                  ; fully qualified pathname
   name                                  ; Bookmark tag
   position                              ; Offset in ms from start
@@ -77,30 +75,33 @@ Automatically becomes buffer-local when set.")
 
 ;;}}}
 ;;{{{ AMark Functions:
-
-(defun emacspeak-amark-add (path name position)
-  "Add an AMark to the buffer local list of AMarks.
-AMarks are bookmarks in audio content."
-  (interactive "fPath\nsName\nnPosition")
-  (declare (special emacspeak-amark-list))
-  (push
-   (make-emacspeak-amark :path path
-                         :name name
-                         :position position )
-   emacspeak-amark-list))
+(defun emacspeak-amark-names ()
+  "Return list of  amark names."
+  (cl-declare (special emacspeak-amark-list))
+  (cl-loop for a in emacspeak-amark-list collect (emacspeak-amark-name a)))
 
 (defun emacspeak-amark-find (name)
   "Return matching AMark if found in buffer-local AMark list."
-  (interactive
-   (list
-    (completing-read
-     "Name: "
-     (loop for a in emacspeak-amark-list
-           collect (emacspeak-amark-name a)))))
-  (declare (special emacspeak-amark-list))
-  (find name emacspeak-amark-list
-        :test #'(lambda (name item)
-                  (string= name (emacspeak-amark-name item)))))
+  (interactive (list (completing-read "Name: " (emacspeak-amark-names))))
+  (cl-declare (special emacspeak-amark-list))
+  (cl-find name emacspeak-amark-list :test #'string= :key #'emacspeak-amark-name))
+
+(defun emacspeak-amark-add (path name position)
+  "Add an AMark to the buffer local list of AMarks. AMarks are
+bookmarks in audio content. If there is an existing amark of the
+given name, it is updated with path and position."
+  (interactive "fPath\nsName\nnPosition")
+  (cl-declare (special emacspeak-amark-list))
+  (let ((amark (emacspeak-amark-find name)))
+    (when (and path (not (zerop (length path))))
+      (cond
+       (amark                             ; exists, reposition
+        (setf (emacspeak-amark-path amark) path
+              (emacspeak-amark-position amark) position))
+       (t 
+        (push
+         (make-emacspeak-amark :path path :name name :position position)
+         emacspeak-amark-list))))))
 
 (defvar emacspeak-amark-file ".amarks.el"
   "Name of file used to save AMarks.")
@@ -108,45 +109,41 @@ AMarks are bookmarks in audio content."
 (defun emacspeak-amark-save ()
   "Save buffer-local AMarks in current directory."
   (interactive)
-  (declare (special emacspeak-amark-file))
-  (let ((l emacspeak-amark-list)
-        (buff
-         (find-file-noselect
-          (expand-file-name emacspeak-amark-file default-directory))))
-    (save-excursion
-      (set-buffer buff)
+  (cl-declare (special  emacspeak-amark-file))
+  (let ((l  emacspeak-amark-list)
+        (print-length nil)
+        (buff (find-file-noselect (expand-file-name emacspeak-amark-file))))
+    (with-current-buffer buff
       (setq buffer-undo-list t)
       (erase-buffer)
-      (print  l buff) 
-      (save-buffer buff)
+      (prin1  l (current-buffer)) 
+      (save-buffer)
       (kill-buffer buff)
-      (when (ems-interactive-p )
-        (message "Saved AMarks in %s"
-                 default-directory)
-        (emacspeak-auditory-icon 'save-object)))))
+      (message "Saved AMarks in %s" emacspeak-amark-file)
+      (emacspeak-auditory-icon 'save-object))))
 
 (defun emacspeak-amark-load ()
   "Locate AMarks file from current directory, and load it."
   (interactive)
-  (declare (special emacspeak-amark-list
-                    emacspeak-amark-file))
+  (cl-declare (special emacspeak-amark-list
+                       emacspeak-amark-file))
   (let ((buff nil)
         (l nil)
         (where
          (locate-dominating-file default-directory emacspeak-amark-file)))
     (cond
      ((null where)
-      (when (ems-interactive-p )
+      (when (called-interactively-p 'interactive)
         (message "No AMarks found.")))
      (t (setq buff
               (find-file-noselect (expand-file-name emacspeak-amark-file where)))
-        (save-excursion
+        (save-current-buffer
           (set-buffer buff)
           (goto-char (point-min))
           (setq l (read buff))
           (kill-buffer buff))
         (setq emacspeak-amark-list l)
-        (when (ems-interactive-p )
+        (when (called-interactively-p 'interactive)
           (emacspeak-auditory-icon 'open-object)
           (message "Loaded AMarks from %s" where))))))
 
@@ -156,7 +153,7 @@ AMarks are bookmarks in audio content."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
