@@ -1,5 +1,5 @@
-;;; emacspeak-ansi-color.el --- Speech-enable ansi-color terminal
-;;; $Id: emacspeak-ansi-color.el 7378 2011-11-10 17:34:32Z tv.raman.tv $
+;;; emacspeak-ansi-color.el --- Speech-enable ansi-color terminal  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for ansi-color
 ;;; Keywords: Emacspeak, ansi-color
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -52,58 +52,36 @@
 ;;{{{ required modules
 
 ;;; Code:
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ color to voice
 
 (defun emacspeak-ansi-color-to-voice (face-spec)
   "Return a voice corresponding to specified face-spec."
-  (declare (special ansi-color-names-vector
-                    ansi-color-faces-vector))
-  (let* ((voice-name nil)
-         (style (cadr face-spec))
-         (style-index (position style ansi-color-faces-vector))
-         (color (cdr (assq 'foreground-color  face-spec)))
-         (color-index
-          (when color
-            (position  color ansi-color-names-vector
-                       :test #'string-equal)))
-         (style nil)
-         (color-parameter nil)
-         (style-parameter nil))
-    (setq voice-name
-          (intern (format "emacspeak-ansi-color-%s-%s"
-                          (if color color "default")
-                          (if style style "default"))))
-    (unless (tts-voice-defined-p voice-name)
-      (setq style (make-acss ))
-      (setq style-parameter
-            (if style-index
-                (+ 1 style-index)
-              1))
-      (setq color-parameter
-            (if color-index
-                (+ 1 color-index)
-              1))
-      (setf (acss-average-pitch style) color-parameter)
-      (setf (acss-pitch-range style) color-parameter)
-      (setf (acss-richness style) color-parameter)
-      (setf (acss-stress style) color-parameter)
-      (tts-define-voice-from-speech-style voice-name style))
-    voice-name))
-
-(defadvice ansi-color-set-extent-face (after emacspeak pre act comp)
-  "Apply aural properties."
-  (let* ((extent (ad-get-arg 0))
-         (face (ad-get-arg 1))
-         (start (overlay-start extent))
-         (end (overlay-end extent))
-         (voice (when (listp face)
-                  (emacspeak-ansi-color-to-voice face))))
-    (when voice
-      (funcall emacspeak-personality-voiceify-faces
-               start end
-               voice nil))))
+  (cl-declare (special ansi-color-names-vector ansi-color-faces-vector))
+  (condition-case nil
+      (let* ((voice-name nil)
+             (color (cdr (assq 'foreground-color  face-spec)))
+             (color-index
+              (when color
+                (cl-position  color ansi-color-names-vector
+                              :test #'string-equal)))
+             (style nil)
+             (color-parameter nil))
+        (setq style (make-acss))
+        (setq color-parameter
+              (if color-index
+                  (+ 1 color-index)
+                1))
+        (setf (acss-average-pitch style) color-parameter)
+        (setf (acss-pitch-range style) color-parameter)
+        (setf (acss-richness style) color-parameter)
+        (setf (acss-stress style) color-parameter)
+        (setq voice-name (acss-personality-from-speech-style  style))
+        voice-name)
+    (error nil)))
 
 ;;}}}
 ;;{{{ advice interactive commands
@@ -111,14 +89,14 @@
 (defadvice ansi-color-for-comint-mode-on (after emacspeak
                                                 pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'on)
     (message "Ansi escape sequences will be processed.")))
 
 (defadvice ansi-color-for-comint-mode-off (after emacspeak
                                                  pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'off)
     (message "Ansi escape sequences will not be processed.")))
 
