@@ -1,5 +1,5 @@
-;;; emacspeak-calculator.el --- Speech enable  desktop calculator
-;;; $Id: emacspeak-calculator.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-calculator.el --- Speech enable  desktop calculator  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable desktop calculator
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,6 +40,7 @@
 
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
@@ -62,7 +63,7 @@
 (defadvice calculator (around emacspeak pre act comp)
   "Fix while waiting for a bug-fix in Emacs."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     (let ((header-line-format nil))
       ad-do-it))
    (t ad-do-it))
@@ -70,14 +71,14 @@
 
 (defadvice calculator (after emacspeak pre act comp)
   "Speech enable calculator."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Welcome to the pocket calculator.")))
 
 (defadvice calculator-digit (around emacspeak pre act comp)
   "Speak the digit."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     (let ((start (point)))
       ad-do-it
       (emacspeak-speak-region start (point))))
@@ -87,7 +88,7 @@
 (defadvice calculator-exp (around emacspeak pre act comp)
   "Speak the digit."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     (let ((start (point)))
       ad-do-it
       (emacspeak-speak-region start (point))))
@@ -97,7 +98,7 @@
 (defadvice calculator-op (around emacspeak pre act comp)
   "Speak the digit."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     ad-do-it
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-calculator-summarize))
@@ -106,7 +107,7 @@
 (defadvice calculator-op-or-exp (around emacspeak pre act comp)
   "Speak the digit."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     (let ((start (point)))
       ad-do-it
       (emacspeak-speak-region start (point))))
@@ -115,7 +116,7 @@
 (defadvice calculator-open-paren (around emacspeak pre act comp)
   "Speak the digit."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     (let ((start (point)))
       ad-do-it
       (emacspeak-speak-region start (point))))
@@ -125,7 +126,7 @@
 (defadvice calculator-close-paren (around emacspeak pre act comp)
   "Speak the digit."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     (let ((start (point)))
       ad-do-it
       (emacspeak-speak-region start (point))))
@@ -135,7 +136,7 @@
 (defadvice calculator-saved-up (around emacspeak pre act comp)
   "Speak the digit."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     ad-do-it
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-calculator-summarize))
@@ -145,7 +146,7 @@
 (defadvice calculator-saved-down (around emacspeak pre act comp)
   "Speak the digit."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     ad-do-it
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-calculator-summarize))
@@ -155,29 +156,29 @@
 (defadvice calculator-save-on-list (after emacspeak pre act
                                           comp)
   "Provide speech feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)
     (emacspeak-calculator-summarize)))
 
 (defadvice calculator-clear-saved (after emacspeak pre act
                                          comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-calculator-summarize)))
 
 (defadvice calculator-enter (after emacspeak pre act comp)
   "Provide speech feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-calculator-summarize)))
 
 (defadvice calculator-backspace (around emacspeak pre act)
   "Speak character you're deleting."
   (cond
-   ((interactive-p )
-    (dtk-tone 500 30 'force)
-    (emacspeak-speak-this-char (preceding-char ))
+   ((ems-interactive-p)
+    (dtk-tone 500 100 'force)
+    (emacspeak-speak-this-char (preceding-char))
     ad-do-it)
    (t ad-do-it))
   ad-return-value)
@@ -185,35 +186,35 @@
 (defadvice calculator-clear (after emacspeak pre act
                                    comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-calculator-summarize)))
 (defadvice calculator-copy (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-current-kill 1)))
 
 (defadvice calculator-paste (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'yank-object)))
 
 (defadvice calculator-get-register (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-calculator-summarize)))
 (defadvice calculator-quit (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
-    (emacspeak-speak-mode-line )))
+    (emacspeak-speak-mode-line)))
 (defadvice calculator-save-and-quit (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
-    (emacspeak-speak-mode-line )))
+    (emacspeak-speak-mode-line)))
 
 (defadvice calculator-update-display (after emacspeak pre
                                             act comp)
@@ -222,7 +223,7 @@
 
 ;;}}}
 ;;{{{  keys 
-(declaim (special calculator-mode-map))
+(cl-declaim (special calculator-mode-map))
 (when (boundp 'calculator-mode-map)
   (define-key calculator-mode-map "k" 'calculator-copy)
   (define-key calculator-mode-map "p" 'calculator-paste)
