@@ -1,5 +1,5 @@
-;;; emacspeak-calendar.el --- Speech enable Emacs Calendar -- maintain a diary and appointments
-;;; $Id: emacspeak-calendar.el 8276 2013-03-30 15:19:30Z tv.raman.tv $
+;;; emacspeak-calendar.el --- Speech enable Emacs Calendar -- maintain a diary and appointments  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extensions to speech enable the calendar.
 ;;; Keywords: Emacspeak, Calendar, Spoken Output
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -37,26 +37,30 @@
 
 ;;}}}
 ;;{{{  Introduction:
-
+;;; Commentary:
 ;;; This module speech enables the Emacs Calendar.
 ;;; Speech enabling is not the same as speaking the screen:
-;;; This is an excellent example of this.
-
+;;; This is an excellent example of the advantages of speech-enabled  interaction.
+;;; Code:
 ;;}}}
 ;;{{{ required modules
 ;;; Code:
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'calendar)
+(require 'solar)
+(require 'g-utils)
+(require 'appt)
 ;;}}}
 ;;{{{  personalities
 (voice-setup-add-map
  '(
    (calendar-today voice-lighten)
-   (holiday-face voice-brighten-extra)
-   (diary-face voice-bolden)
+   (holiday voice-brighten-extra)
+   (diary voice-bolden)
    ))
 
-(defcustom emacspeak-calendar-mark-personality 'ursula
+(defcustom emacspeak-calendar-mark-personality voice-bolden
   "Personality to use when showing marked calendar entries."
   :type 'symbol
   :group 'emacspeak-calendar)
@@ -65,15 +69,15 @@
 ;;{{{  functions:
 (defun emacspeak-calendar-sort-diary-entries ()
   "Sort entries in diary entries list."
-  (declare (special diary-entries-list))
+  (cl-declare (special diary-entries-list))
   (when(and  (boundp 'diary-entries-list)
              diary-entries-list)
     (setq diary-entries-list
           (sort  diary-entries-list
-                 #'(lambda (a b )
-                     (string-lessp (cadr a) (cadr b )))))))
+                 #'(lambda (a b)
+                     (string-lessp (cadr a) (cadr b)))))))
 
-(defsubst emacspeak-calendar-entry-marked-p()
+(defun emacspeak-calendar-entry-marked-p()
   "Check if diary entry is marked. "
   (member 'diary
           (delq nil
@@ -97,7 +101,7 @@
 (defadvice calendar-exchange-point-and-mark (after emacspeak
                                                    pre act comp)
   "Speak date under point"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-calendar-speak-date)))
 
@@ -105,51 +109,46 @@
                                     pre act
                                     comp)
   "Speak date under point"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-calendar-speak-date)))
 
-(declaim (special diary-display-hook))
-(when (boundp 'diary-display-hook)
-  (unless (memq 'fancy-diary-display diary-display-hook)
-    (add-hook 'diary-display-hook 'fancy-diary-display)))
-(add-hook 'calendar-mode-hook
-          'gcal-emacs-calendar-setup)
 (add-hook 'calendar-mode-hook
           'emacspeak-calendar-setup)
 
-(loop for f in
-      '(fancy-diary-display simple-diary-display
-                            diary-list-entries)
-      do
-      (eval
-       `(defadvice ,f (around emacspeak pre act com)
-          "Silence messages."
-          (let ((emacspeak-speak-messages (not (ems-interactive-p ))))
-            ad-do-it))))
+(cl-loop for f in
+         '(fancy-diary-display simple-diary-display
+                               diary-list-entries)
+         do
+         (eval
+          `(defadvice ,f (around emacspeak pre act com)
+             "Silence messages."
+             (let ((emacspeak-speak-messages (not (ems-interactive-p))))
+               ad-do-it))))
 
 (defadvice view-diary-entries (after emacspeak pre act)
   "Speak the diary entries."
-  (when (ems-interactive-p )
-    (let ((emacspeak-speak-messages nil))
-      (cond
-       ((buffer-live-p (get-buffer "*Fancy Diary Entries*"))
-        (save-excursion
-          (set-buffer "*Fancy Diary Entries*")
-          (tts-with-punctuations "some"
-                                 (emacspeak-speak-buffer))))
-       (t (dtk-speak "No diary entries."))))))
+  (when (ems-interactive-p)
+    (ems-with-messages-silenced
+     (cond
+      ((buffer-live-p (get-buffer "*Fancy Diary Entries*"))
+       (save-current-buffer
+         (set-buffer "*Fancy Diary Entries*")
+         (tts-with-punctuations
+          "some"
+          (emacspeak-speak-buffer))))
+      (t (dtk-speak "No diary entries."))))))
 
-(defadvice  mark-visible-calendar-date (after emacspeak pre act )
+(defadvice  mark-visible-calendar-date (after emacspeak pre act)
   "Use voice locking to mark date. "
-  (let ((date (ad-get-arg 0 )))
+  (let ((date (ad-get-arg 0)))
     (if (calendar-date-is-valid-p date)
-        (save-excursion
+        (save-current-buffer
           (set-buffer calendar-buffer)
           (calendar-cursor-to-visible-date date)
-          (ems-modify-buffer-safely
-           (put-text-property  (1-(point)) (1+ (point))
-                               'personality   emacspeak-calendar-mark-personality ))))))
+          (with-silent-modifications
+            (put-text-property  (1-(point)) (1+ (point))
+                                'personality   emacspeak-calendar-mark-personality))))))
 
 (defvar emacspeak-calendar-mode-line-format
   '((calendar-date-string (calendar-current-date))  "Calendar")
@@ -159,13 +158,13 @@
   '((:eval (calendar-date-string (calendar-cursor-to-date t))))
   "Header line used by Emacspeak in calendar.")
 
-(declaim (special calendar-mode-line-format))
+(cl-declaim (special calendar-mode-line-format))
 (setq calendar-mode-line-format
       emacspeak-calendar-mode-line-format)
 
-(defadvice calendar (after emacspeak pre act )
+(defadvice calendar (after emacspeak pre act)
   "Announce yourself."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (when emacspeak-use-header-line
       (setq header-line-format
@@ -177,113 +176,113 @@
 
 (defadvice calendar-goto-date (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p  )
-    (emacspeak-calendar-speak-date ))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date))
   (emacspeak-auditory-icon 'select-object))
 
 (defadvice calendar-goto-today (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p  )
-    (emacspeak-calendar-speak-date ))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date))
 
   (emacspeak-auditory-icon 'select-object))
 
 (defadvice calendar-backward-day (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice calendar-forward-day (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice calendar-backward-week (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
-    (emacspeak-auditory-icon 'large-movement)))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
+    (emacspeak-auditory-icon 'paragraph)))
 
 (defadvice calendar-forward-week (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
-    (emacspeak-auditory-icon 'large-movement)))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
+    (emacspeak-auditory-icon 'paragraph)))
 
 (defadvice calendar-backward-month (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
-    (emacspeak-auditory-icon 'large-movement)))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
+    (emacspeak-auditory-icon 'section)))
 
 (defadvice calendar-forward-month (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
-    (emacspeak-auditory-icon 'large-movement)))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
+    (emacspeak-auditory-icon 'section)))
 
 (defadvice calendar-backward-year (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice calendar-forward-year (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice calendar-beginning-of-week (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
-    (emacspeak-auditory-icon 'large-movement)))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
+    (emacspeak-auditory-icon 'paragraph)))
 
 (defadvice calendar-beginning-of-month (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
-    (emacspeak-auditory-icon 'large-movement)))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
+    (emacspeak-auditory-icon 'section)))
 
 (defadvice calendar-beginning-of-year (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice calendar-end-of-week (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
-    (emacspeak-auditory-icon 'large-movement)))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
+    (emacspeak-auditory-icon 'paragraph)))
 
 (defadvice calendar-end-of-month (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
-    (emacspeak-auditory-icon 'select-object)))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
+    (emacspeak-auditory-icon 'section)))
 
 (defadvice calendar-end-of-year (after emacspeak pre act)
   "Speak the date. "
-  (when (ems-interactive-p )
-    (emacspeak-calendar-speak-date )
-    (emacspeak-auditory-icon 'select-object)))
-(loop for f in
-      '(exit-calendar calendar-exit calendar-quit)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act)
-          "Speak modeline. "
-          (when (ems-interactive-p  )
-            (emacspeak-auditory-icon 'close-object)
-            (emacspeak-speak-mode-line)))))
+  (when (ems-interactive-p)
+    (emacspeak-calendar-speak-date)
+    (emacspeak-auditory-icon 'large-movement)))
+(cl-loop for f in
+         '(exit-calendar calendar-exit calendar-quit)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act)
+             "Speak modeline. "
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'close-object)
+               (emacspeak-speak-mode-line)))))
 
 (defadvice insert-block-diary-entry (before emacspeak pre act)
   "Speak the line. "
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (let*
         ((cursor (calendar-cursor-to-date t))
          (mark (or (car calendar-mark-ring)
@@ -306,13 +305,13 @@
 
 (defadvice calendar-read (around emacspeak pre act comp)
   "Record what was read"
-  (declare (special emacspeak-calendar-user-input))
+  (cl-declare (special emacspeak-calendar-user-input))
   ad-do-it
   (setq emacspeak-calendar-user-input ad-return-value)
   ad-return-value)
 (defadvice insert-anniversary-diary-entry (before emacspeak pre act)
   "Speak the line. "
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Anniversary entry for %s"
              (calendar-date-string
@@ -320,7 +319,7 @@
 
 (defadvice insert-cyclic-diary-entry (after emacspeak pre act)
   "Speak the line. "
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Insert cyclic diary entry that repeats every
 %s days"
@@ -328,62 +327,58 @@
 
 (defadvice insert-diary-entry (after emacspeak pre act)
   "Speak the line. "
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
-    (emacspeak-speak-line )))
+    (emacspeak-speak-line)))
 
 (defadvice insert-weekly-diary-entry (before emacspeak pre act)
   "Speak the line. "
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Weekly diary entry for %s"
              (calendar-day-name (calendar-cursor-to-date t)))))
 
 (defadvice insert-yearly-diary-entry (before emacspeak pre act)
   "Speak the line. "
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Yearly diary entry for %s %s"
-             (calendar-month-name(first (calendar-cursor-to-date t)))
-             (second (calendar-cursor-to-date t)))))
+             (calendar-month-name(cl-first (calendar-cursor-to-date t)))
+             (cl-second (calendar-cursor-to-date t)))))
 
 (defadvice insert-monthly-diary-entry (before emacspeak pre act)
   "Speak the line. "
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Monthly diary entry for %s"
-             (second (calendar-cursor-to-date t)))))
+             (cl-second (calendar-cursor-to-date t)))))
 
 (defadvice calendar-cursor-holidays (after emacspeak pre act comp)
   "Speak the displayed holidays"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-speak-message-again)))
 
 (defadvice mark-diary-entries (around emacspeak pre act comp)
   "Silence messages."
-  (let ((emacspeak-speak-messages nil))
-    ad-do-it
-    ad-return-value))
+  (ems-with-messages-silenced
+   ad-do-it
+   ad-return-value))
 
 ;;}}}
 ;;{{{  keymap
-(eval-when (load))
+(cl-eval-when (load))
 
 (defun emacspeak-calendar-setup()
   "Set up appropriate bindings for calendar"
-  (declare (special calendar-buffer calendar-mode-map emacspeak-prefix ))
-  (save-excursion
+  (cl-declare (special calendar-buffer calendar-mode-map emacspeak-prefix))
+  (save-current-buffer
     (set-buffer calendar-buffer)
     (local-unset-key emacspeak-prefix)
     (define-key calendar-mode-map "v" 'view-diary-entries)
     (define-key calendar-mode-map "\M-s" 'emacspeak-wizards-sunrise-sunset)
     (define-key calendar-mode-map  "\C-e." 'emacspeak-calendar-speak-date)
     (define-key calendar-mode-map  "\C-ee"
-      'calendar-end-of-week)
-    )
-  (add-hook 'initial-calendar-window-hook
-            (function (lambda ()
-                        ))))
+      'calendar-end-of-week)))
 
                                         ;(add-hook 'calendar-initial-window-hook 'emacspeak-calendar-setup t)
 
@@ -393,27 +388,26 @@
 ;;{{{ take over and speak the appointment
 
 ;;; For the present, we just take over and speak the appointment.
-(eval-when (compile)
-  (load-library "appt"))
-(declaim (special appt-display-duration ))
+
+(cl-declaim (special appt-display-duration))
 (setq appt-display-duration 90)
 
-(defun emacspeak-appt-speak-appointment (minutes-left new-time message )
+(defun emacspeak-appt-speak-appointment (minutes-left new-time message)
   "Speak the appointment in addition to  displaying it visually."
-  (let ((emacspeak-speak-messages-pause nil))
-    (emacspeak-auditory-icon 'alarm)
-    (message "You have an appointment in %s minutes. %s"
-             minutes-left message )
-    (appt-disp-window minutes-left new-time  message)))
+  (emacspeak-auditory-icon 'alarm)
+  (message "You have an appointment in %s minutes. %s"
+           minutes-left message)
+  (appt-disp-window minutes-left new-time  message))
 
 (defun emacspeak-appt-delete-display ()
   "Function to delete appointment message"
   (and (get-buffer appt-buffer-name)
-       (save-excursion
+       (save-current-buffer
          (set-buffer appt-buffer-name)
          (erase-buffer))))
-(declaim (special appt-delete-window
-                  appt-disp-window-function))
+
+(cl-declaim (special appt-delete-window
+                     appt-disp-window-function))
 
 (setq appt-disp-window-function 'emacspeak-appt-speak-appointment)
 (setq appt-delete-window 'emacspeak-appt-delete-display)
@@ -421,28 +415,26 @@
 (defun emacspeak-appt-repeat-announcement ()
   "Speaks the most recently displayed appointment message if any."
   (interactive)
-  (declare (special appt-buffer-name))
+  (cl-declare (special appt-buffer-name))
   (let  ((appt-buffer (get-buffer appt-buffer-name)))
     (cond
-     ( appt-buffer
-       (save-excursion
-         (set-buffer  appt-buffer)
-         (emacspeak-dtk-sync)
-         (if (= (point-min) (point-max))
-             (message  "No appointments are currently displayed")
-           (dtk-speak (buffer-string )))))
-     (t (message "You have no appointments "))))
-  (emacspeak-dtk-sync))
+     (appt-buffer
+      (save-current-buffer
+        (set-buffer  appt-buffer)
+        (if (= (point-min) (point-max))
+            (message  "No appointments are currently displayed")
+          (dtk-speak (buffer-string)))))
+     (t (dtk-speak-and-echo "You have no appointments ")))))
 
 ;;}}}
 
-(defadvice appt-add (after emacspeak pre act )
+(defadvice appt-add (after emacspeak pre act)
   "Confirm that the alarm got set."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (let ((time (ad-get-arg 0))
-          (message (ad-get-arg 1 )))
+          (message (ad-get-arg 1)))
       (message "Set alarm %s at %s"
-               message time ))))
+               message time))))
 
 ;;}}}
 ;;{{{ Use GWeb if available for configuring sunrise/sunset coords
@@ -451,25 +443,26 @@
   "Set up geo-coordinates using Google Maps reverse geocoding.
 To use, configure variable gweb-my-address via M-x customize-variable."
   (interactive)
-  (declare (special gweb-my-location gweb-my-address
-                    calendar-latitude calendar-longitude))
+  (cl-declare (special  gweb-my-address gweb-my-location
+                        calendar-latitude calendar-longitude))
   (cond
    ((null gweb-my-location)
-    (message "First configure gweb-my-address."))
+    (message "First customize gweb-my-address."))
    (t
-    (setq calendar-latitude
-          (g-json-get 'lat gweb-my-location)
-          calendar-longitude (g-json-get 'lng gweb-my-location))
-    (message "Setup for %s"
-             gweb-my-address))))
+    (setq
+     calendar-latitude
+     (g-json-get 'lat (gmaps-address-geocode gweb-my-address))
+     calendar-longitude
+     (g-json-get 'lng (gmaps-address-geocode gweb-my-address)))
+    (message "Setup for %s" gweb-my-address))))
 
 (defadvice calendar-sunrise-sunset (around emacspeak pre act comp)
   "Like calendar's sunrise-sunset, but speaks location intelligently."
-  (declare (special gweb-my-address))
+  (cl-declare (special gweb-my-address))
   (cond
    ((and (boundp 'gweb-my-address)
          gweb-my-address
-         (ems-interactive-p ))
+         (ems-interactive-p))
     (let ((date (calendar-cursor-to-date t)))
       (message "%s at %s"
                (solar-sunrise-sunset-string date 'nolocation)
@@ -479,27 +472,27 @@ To use, configure variable gweb-my-address via M-x customize-variable."
 ;;}}}
 ;;{{{ Lunar Phases
 
-(loop for f in
-      '(calendar-lunar-phases lunar-phases phases-of-moon)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (ems-interactive-p )
-            (with-current-buffer lunar-phases-buffer
-              (emacspeak-auditory-icon 'open-object)
-              (emacspeak-speak-buffer))))))
+(cl-loop for f in
+         '(calendar-lunar-phases lunar-phases phases-of-moon)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Provide auditory feedback."
+             (when (ems-interactive-p)
+               (with-current-buffer lunar-phases-buffer
+                 (emacspeak-auditory-icon 'open-object)
+                 (emacspeak-speak-buffer))))))
 
-(loop for f in
-      '(holidays calendar-list-holidays)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (ems-interactive-p )
-            (with-current-buffer holiday-buffer
-              (emacspeak-auditory-icon 'open-object)
-              (emacspeak-speak-buffer))))))
+(cl-loop for f in
+         '(holidays calendar-list-holidays)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Provide auditory feedback."
+             (when (ems-interactive-p)
+               (with-current-buffer holiday-buffer
+                 (emacspeak-auditory-icon 'open-object)
+                 (emacspeak-speak-buffer))))))
 
 ;;}}}
 (provide 'emacspeak-calendar)
@@ -507,7 +500,7 @@ To use, configure variable gweb-my-address via M-x customize-variable."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
