@@ -1,5 +1,5 @@
-;;; emacspeak-checkdoc.el --- Speech-enable checkdoc
-;;; $Id: emacspeak-checkdoc.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-checkdoc.el --- Speech-enable checkdoc  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:Speech-enable checkdoc
 ;;; Keywords: Emacspeak, Speak, Spoken Output, maintain code 
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2018, T. V. Raman 
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -48,23 +48,11 @@
 
 ;;}}}
 ;;; Code:
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ implementation
 
-(defadvice checkdoc (around emacspeak pre act comp)
-  "Advice read-event temporarily."
-  (cond
-   ((interactive-p)
-    (save-match-data
-      (ad-enable-advice  'read-event 'before 'emacspeak-checkdoc )
-      (ad-activate 'read-event)
-      ad-do-it
-      (ad-disable-advice  'read-event 'before 'emacspeak-checkdoc )
-      (ad-deactivate 'read-event)))
-   (t  ad-do-it))
-  ad-return-value)
-
 (provide 'emacspeak-checkdoc-advice)
 
 ;;; checkdoc-advice.el ends here
