@@ -1,5 +1,5 @@
-;;; emacspeak-cmuscheme.el --- Scheme support for emacspeak
-;;; $Id: emacspeak-cmuscheme.el 7378 2011-11-10 17:34:32Z tv.raman.tv $
+;;; emacspeak-cmuscheme.el --- Scheme support for emacspeak  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Speech-enable emacs for scheme and guile
 ;;; Keywords: Emacspeak, cmuscheme
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -50,6 +50,7 @@
 
 ;;; Code:
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ advice interactive commands.
@@ -59,20 +60,20 @@
 (defadvice inferior-scheme-mode (after emacspeak pre act
                                        comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'task-done)
     (message "Welcome to inferior scheme mode.")))
 
 (defadvice run-scheme (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'task-done)
     (message "Launched scheme %s"
              (ad-get-arg 0))))
 
 (defadvice scheme-send-region (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (message "Sent %s lines to scheme. "
              (count-lines (region-beginning)
@@ -80,19 +81,19 @@
 
 (defadvice scheme-send-definition (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (message "Sent definition   to scheme. ")))
 
 (defadvice scheme-send-last-sexp (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (message "Sent last sexp  to scheme. ")))
 
 (defadvice scheme-compile-region (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (message "Compiling  %s lines to scheme. "
              (count-lines (region-beginning)
@@ -100,36 +101,36 @@
 
 (defadvice scheme-compile-definition (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (message "Compiled definition  to scheme. ")))
 
 (defadvice switch-to-scheme  (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice scheme-send-region-and-go (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice scheme-send-definition-and-go (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 (defadvice scheme-load-file (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (message "loaded scheme file %s"
              (ad-get-arg 0))))
 (defadvice scheme-compile-file (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (message "Compiled scheme file %s"
              (ad-get-arg 0))))
