@@ -1,5 +1,5 @@
-;;; emacspeak-cperl.el --- Speech enable CPerl Mode 
-;;; $Id: emacspeak-cperl.el 7322 2011-10-26 00:43:56Z tv.raman.tv $
+;;; emacspeak-cperl.el --- Speech enable CPerl Mode  -*- lexical-binding: t; -*- 
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for CPerl mode
 ;;; Keywords:emacspeak, audio interface to emacs CPerl
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2018, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -39,6 +39,7 @@
 
 ;;{{{ required modules 
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
@@ -65,24 +66,26 @@
     cperl-electric-semi
     cperl-electric-terminator)
   "Electric commands from CPerl to advice")
-
-(loop for e in emacspeak-cperl-electric-insertion-commands-to-advice
-      do
-      (eval
-       `(defadvice ,e (after emacspeak pre act comp)
-          "Speak what you inserted.
+(unless (and (boundp 'post-self-insert-hook)
+             post-self-insert-hook
+             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
+  (cl-loop for e in emacspeak-cperl-electric-insertion-commands-to-advice
+           do
+           (eval
+            `(defadvice ,e (after emacspeak pre act comp)
+               "Speak what you inserted.
 Cue electric insertion with a tone."
-          (when (interactive-p)
-            (let ((emacspeak-speak-messages nil))
-              (emacspeak-speak-this-char last-input-event)
-              (dtk-tone 800 50 t))))))
+               (when (ems-interactive-p)
+                 (let ((emacspeak-speak-messages nil))
+                   (emacspeak-speak-this-char last-input-event)
+                   (dtk-tone 800 100 t)))))))
 
 (defadvice cperl-electric-backspace (around emacspeak pre act)
   "Speak character you're deleting."
   (cond
-   ((interactive-p )
-    (dtk-tone 500 30 'force)
-    (emacspeak-speak-this-char (preceding-char ))
+   ((ems-interactive-p)
+    (dtk-tone 500 100 'force)
+    (emacspeak-speak-this-char (preceding-char))
     ad-do-it)
    (t ad-do-it))
   ad-return-value)
@@ -91,12 +94,12 @@ Cue electric insertion with a tone."
   "Speak the previous line if line echo is on. 
   See command \\[emacspeak-toggle-line-echo].
 Otherwise cue user to the line just created. "
-  (declare (special emacspeak-line-echo ))
+  (cl-declare (special emacspeak-line-echo))
   (cond
-   ((interactive-p)
+   ((ems-interactive-p)
     (cond
      (emacspeak-line-echo 
-      (emacspeak-speak-line )
+      (emacspeak-speak-line)
       ad-do-it)
      (t ad-do-it       
         (dtk-speak-using-voice voice-annotate
@@ -109,8 +112,8 @@ Otherwise cue user to the line just created. "
 
 (defadvice cperl-indent-exp  (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
-    (emacspeak-auditory-icon 'fill-object )
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'fill-object)
     (message "Indented current s expression ")))
 
 ;;}}}
@@ -118,7 +121,7 @@ Otherwise cue user to the line just created. "
 
 (defadvice cperl-info-on-current-command (after emacspeak pre act comp)
   "Speak the displayed info"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'help)
     (message "Displayed info in other window")))
 
@@ -126,7 +129,7 @@ Otherwise cue user to the line just created. "
                                         pre act
                                         comp)
   "Speak the displayed info"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'help)
     (message "Displayed help in other window.")))
 
@@ -136,13 +139,13 @@ Otherwise cue user to the line just created. "
 (defadvice cperl-invert-if-unless (after emacspeak pre act
                                          comp)
   "Speak updated line"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
-(defadvice cperl-comment-region (after emacspeak pre act )
+(defadvice cperl-comment-region (after emacspeak pre act)
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (let ((prefix-arg (ad-get-arg 2)))
       (message "%s region containing %s lines"
                (if (and prefix-arg
@@ -151,9 +154,9 @@ Otherwise cue user to the line just created. "
                  "Commented")
                (count-lines (point) (mark))))))
 
-(defadvice cperl-uncomment-region (after emacspeak pre act )
+(defadvice cperl-uncomment-region (after emacspeak pre act)
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (let ((prefix-arg (ad-get-arg 2)))
       (message "%s region containing %s lines"
                (if (and prefix-arg
@@ -165,22 +168,22 @@ Otherwise cue user to the line just created. "
 (defadvice cperl-indent-command (after emacspeak pre act
                                        comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice cperl-indent-region (after emacspeak pre act
                                       comp)
   "Provide auditory feedback when done"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'fill-object)
     (message "Filled region containing %s lines"
              (count-lines (region-beginning)
                           (region-end)))))
 (defadvice cperl-fill-paragraph (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
-    (emacspeak-auditory-icon 'fill-object )
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'fill-object)
     (message "Filled current paragraph")))
 ;;}}}
 ;;{{{  misc
@@ -188,27 +191,26 @@ Otherwise cue user to the line just created. "
 (defadvice cperl-switch-to-doc-buffer (after emacspeak pre
                                              act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'open-object)))
 
 (defadvice cperl-find-bad-style (after emacspeak pre act
                                        comp)
   "Provide auditory feedback when done."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'task-done)))
 ;;}}}
 ;;{{{ set up hooks 
 
 (add-hook 'cperl-mode-hook
-          (function (lambda ()
-                      (dtk-set-punctuations 'all)
-                      (or dtk-split-caps
-                          (dtk-toggle-split-caps))
-                      (or emacspeak-audio-indentation
-                          (emacspeak-toggle-audio-indentation))
-                      (emacspeak-dtk-sync))))
+          #'(lambda ()
+              (dtk-set-punctuations 'all)
+              (or dtk-split-caps
+                  (dtk-toggle-split-caps))
+              (or emacspeak-audio-indentation
+                  (emacspeak-toggle-audio-indentation))))
 
 ;;}}}
 (provide  'emacspeak-cperl)
