@@ -1,6 +1,4 @@
-;;; emacspeak-dismal.el --- Speech enable Dismal -- An Emacs Spreadsheet program
-;;; $Id: emacspeak-dismal.el 7322 2011-10-26 00:43:56Z tv.raman.tv $
-;;; $Author: tv.raman.tv $ 
+;;; emacspeak-dismal.el --- Speech enable Dismal -- An Emacs Spreadsheet program  -*- lexical-binding: t; -*-
 ;;; Description: spread sheet extension
 ;;; Keywords:emacspeak, audio interface to emacs spread sheets
 ;;{{{  LCD Archive entry: 
@@ -15,7 +13,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2018, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -36,16 +34,30 @@
 ;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ;;}}}
-
 ;;{{{  Introduction
 
 ;;; emacspeak extensions to the dismal spreadsheet. 
 ;;; Dismal can be found at ftp://cs.nyu.edu/pub/local/fox/dismal
+;;; Code:
 
 ;;}}}
 ;;{{{  requires 
-(require 'cl)
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
+;;}}}
+;;{{{ Forward Decls:
+
+(declare-function dismal-get-val "ext:dismal" (r c))
+(declare-function  dismal-convert-cellexpr-to-string "dismal" (sexp))
+(declare-function dismal-get-exp "dismal" (r c))
+(declare-function  dismal-display-current-cell-expr "dismal" (r c))
+(declare-function  dis-forward-row "dismal" (rows))
+(declare-function dis-backward-row "dismal" (rows))
+(declare-function  dis-forward-column "dismal" (cols))
+(declare-function  dis-backward-column "dismal" (cols))
+(declare-function dis-recalculate-matrix "dismal" nil)
+
 ;;}}}
 ;;{{{ custom
 
@@ -59,25 +71,25 @@
 
 ;;; return cell value as a string
 
-(defsubst emacspeak-dismal-cell-value (row col)
+(defun emacspeak-dismal-cell-value (row col)
   (let ((value (dismal-get-val row col)))
     (if (floatp value)
         (format "%.2f" value)
       (dismal-convert-cellexpr-to-string value)value)))
 
-(defsubst emacspeak-dismal-current-cell-value ()
-  (declare (special dismal-current-row dismal-current-col))
+(defun emacspeak-dismal-current-cell-value ()
+  (cl-declare (special dismal-current-row dismal-current-col))
   (emacspeak-dismal-cell-value dismal-current-row dismal-current-col))
 
 ;;; return entry in col 0 of current row as a string:
 
-(defsubst emacspeak-dismal-current-row-header ()
-  (declare (special dismal-current-row ))
+(defun emacspeak-dismal-current-row-header ()
+  (cl-declare (special dismal-current-row))
   (dismal-convert-cellexpr-to-string
    (dismal-get-exp dismal-current-row  0)))
 
-(defsubst emacspeak-dismal-current-col-header ()
-  (declare (special dismal-current-col ))
+(defun emacspeak-dismal-current-col-header ()
+  (cl-declare (special dismal-current-col))
   (dismal-convert-cellexpr-to-string
    (dismal-get-exp 0  dismal-current-col)))
 
@@ -87,13 +99,13 @@
 (defun emacspeak-dismal-display-cell-expression ()
   "Display the expression in the message area"
   (interactive)
-  (declare (special dismal-current-row dismal-current-col))
+  (cl-declare (special dismal-current-row dismal-current-col))
   (dismal-display-current-cell-expr dismal-current-row dismal-current-col))
 
 (defun emacspeak-dismal-display-cell-value ()
   "Display the cell value in the message area"
   (interactive)
-  (declare (special dismal-current-cell))
+  (cl-declare (special dismal-current-cell))
   (message "%s = %s"
            dismal-current-cell
            (emacspeak-dismal-current-cell-value)))
@@ -102,7 +114,7 @@
   "Displays current cell along with its row header.
 The `row header' is the entry in column 0."
   (interactive)
-  (declare (special))
+  (cl-declare (special))
   (let ((row-head  (emacspeak-dismal-current-row-header))
         (value (emacspeak-dismal-current-cell-value)))
     (message "%s is %s"
@@ -121,33 +133,29 @@ The `column header' is the entry in row 0."
   "Move forward by arg rows
  (the next row by default)and summarize it."
   (interactive "p")
-  (let ((dismal-interactive-p nil))
-    (dis-forward-row rows)
-    (emacspeak-dismal-row-summarize)))
+  (dis-forward-row rows)
+  (emacspeak-dismal-row-summarize))
 
 (defun emacspeak-dismal-backward-row-and-summarize (rows)
   "Move backward by arg rows
  (the previous row by default)and summarize it."
   (interactive "p")
-  (let ((dismal-interactive-p nil))
-    (dis-backward-row rows)
-    (emacspeak-dismal-row-summarize)))
+  (dis-backward-row rows)
+  (emacspeak-dismal-row-summarize))
 
 (defun emacspeak-dismal-forward-col-and-summarize (cols)
   "Move forward by arg columns
  (the next column by default)and summarize it."
   (interactive "p")
-  (let ((dismal-interactive-p nil))
-    (dis-forward-column cols)
-    (emacspeak-dismal-col-summarize)))
+  (dis-forward-column cols)
+  (emacspeak-dismal-col-summarize))
 
 (defun emacspeak-dismal-backward-col-and-summarize (cols)
   "Move backward by arg columns
  (the previous column by default)and summarize it."
   (interactive "p")
-  (let ((dismal-interactive-p nil))
-    (dis-backward-column cols)
-    (emacspeak-dismal-col-summarize)))
+  (dis-backward-column cols)
+  (emacspeak-dismal-col-summarize))
 
 ;;}}}
 ;;{{{  Intelligent summaries
@@ -179,10 +187,10 @@ The `column header' is the entry in row 0."
   "Summarizes a row using the specification in list
 emacspeak-dismal-row-summarizer-list"
   (interactive)
-  (declare (special emacspeak-dismal-row-summarizer-list
-                    emacspeak-dismal-value-personality
-                    voice-lock-mode
-                    dismal-current-row))
+  (cl-declare (special emacspeak-dismal-row-summarizer-list
+                       emacspeak-dismal-value-personality
+                       voice-lock-mode
+                       dismal-current-row))
   (unless  (and  emacspeak-dismal-row-summarizer-list
                  (vectorp emacspeak-dismal-row-summarizer-list))
     (setq emacspeak-dismal-row-summarizer-list
@@ -203,17 +211,17 @@ emacspeak-dismal-row-summarizer-list"
                                  dismal-current-row token)))
                   (put-text-property  0   (length value)
                                       'personality  emacspeak-dismal-value-personality 
-                                      value )
+                                      value)
                   value)
                  ((and (listp token)
-                       (numberp (first token))
-                       (numberp (second token )))
+                       (numberp (cl-first token))
+                       (numberp (cl-second token)))
                   (setq value
                         (format "%s"
                                 (emacspeak-dismal-cell-value
-                                 (first token)
-                                 (second token))))
-                  (put-text-property 0   (length value )
+                                 (cl-first token)
+                                 (cl-second token))))
+                  (put-text-property 0   (length value)
                                      'personality emacspeak-dismal-value-personality 
                                      value)
                   value)
@@ -226,9 +234,9 @@ emacspeak-dismal-row-summarizer-list"
   "Summarizes a col using the specification in list
 emacspeak-dismal-col-summarizer-list"
   (interactive)
-  (declare (special emacspeak-dismal-col-summarizer-list
-                    emacspeak-dismal-value-personality voice-lock-mode
-                    dismal-current-col))
+  (cl-declare (special emacspeak-dismal-col-summarizer-list
+                       emacspeak-dismal-value-personality voice-lock-mode
+                       dismal-current-col))
   (unless  (and  emacspeak-dismal-col-summarizer-list
                  (vectorp emacspeak-dismal-col-summarizer-list))
     (setq emacspeak-dismal-col-summarizer-list
@@ -252,13 +260,13 @@ emacspeak-dismal-col-summarizer-list"
                                      emacspeak-dismal-value-personality value)
                   value)
                  ((and (listp token)
-                       (numberp (first token))
-                       (numberp (second token )))
+                       (numberp (cl-first token))
+                       (numberp (cl-second token)))
                   (setq value
                         (format "%s"
                                 (emacspeak-dismal-cell-value
-                                 (first token)
-                                 (second token))))
+                                 (cl-first token)
+                                 (cl-second token))))
                   (put-text-property 0 (length value)
                                      'personality
                                      emacspeak-dismal-value-personality value)
@@ -272,7 +280,7 @@ emacspeak-dismal-col-summarizer-list"
   "Summarizes a sheet using the specification in list
 emacspeak-dismal-sheet-summarizer-list"
   (interactive)
-  (declare (special emacspeak-dismal-row-summarizer-list))
+  (cl-declare (special emacspeak-dismal-row-summarizer-list))
   (when emacspeak-dismal-sheet-summarizer-list
     (let ((emacspeak-speak-messages nil))
       (dis-recalculate-matrix))
@@ -283,11 +291,11 @@ emacspeak-dismal-sheet-summarizer-list"
          (cond
           ((stringp token) token)
           ((and (listp token)
-                (numberp (first token))
-                (numberp (second token )))
+                (numberp (cl-first token))
+                (numberp (cl-second token)))
            (emacspeak-dismal-cell-value
-            (first token)
-            (second token)))
+            (cl-first token)
+            (cl-second token)))
           (t  (format "%s" token)))))
       emacspeak-dismal-sheet-summarizer-list 
       " "))))
@@ -295,7 +303,7 @@ emacspeak-dismal-sheet-summarizer-list"
 (defun emacspeak-dismal-set-row-summarizer-list ()
   "Specify or reset row summarizer list."
   (interactive)
-  (declare (special emacspeak-dismal-col-summarizer-list))
+  (cl-declare (special emacspeak-dismal-col-summarizer-list))
   (setq emacspeak-dismal-row-summarizer-list
         (read-minibuffer
          "Specify summarizer as a list: "
@@ -305,7 +313,7 @@ emacspeak-dismal-sheet-summarizer-list"
 (defun emacspeak-dismal-set-col-summarizer-list ()
   "Specify or reset col summarizer list."
   (interactive)
-  (declare (special emacspeak-dismal-col-summarizer-list))
+  (cl-declare (special emacspeak-dismal-col-summarizer-list))
   (setq emacspeak-dismal-col-summarizer-list
         (read-minibuffer
          "Specify summarizer as a vector: "
@@ -315,7 +323,7 @@ emacspeak-dismal-sheet-summarizer-list"
 (defun emacspeak-dismal-set-sheet-summarizer-list ()
   "Specify or reset sheet summarizer list."
   (interactive)
-  (declare (special emacspeak-dismal-sheet-summarizer-list))
+  (cl-declare (special emacspeak-dismal-sheet-summarizer-list))
   (setq emacspeak-dismal-sheet-summarizer-list
         (read-minibuffer
          "Specify summarizer as a list: "
@@ -331,51 +339,39 @@ emacspeak-dismal-sheet-summarizer-list"
 Checked by emacspeak specific dis-mode-hooks entry.")
 
 (add-hook 'dis-mode-hooks
-          (function
-           (lambda nil
-             (declare (special dismal-saved-variables))
-             (unless emacspeak-dismal-already-customized-dismal
-               (setq emacspeak-dismal-already-customized-dismal t)
-               (push 'emacspeak-dismal-sheet-summarizer-list
-                     dismal-saved-variables)
-               (push 'emacspeak-dismal-row-summarizer-list
-                     dismal-saved-variables)
-               (push 'emacspeak-dismal-col-summarizer-list
-                     dismal-saved-variables)))))
+          #'(lambda nil
+              (cl-declare (special dismal-saved-variables dismal-map))
+              (define-key dismal-map (concat emacspeak-prefix "e")
+                'dis-last-column)
+              (define-key dismal-map emacspeak-prefix 'emacspeak-prefix-command)
+              (unless emacspeak-dismal-already-customized-dismal
+                (setq emacspeak-dismal-already-customized-dismal t)
+                (push 'emacspeak-dismal-sheet-summarizer-list
+                      dismal-saved-variables)
+                (push 'emacspeak-dismal-row-summarizer-list
+                      dismal-saved-variables)
+                (push 'emacspeak-dismal-col-summarizer-list
+                      dismal-saved-variables))))
 
-(declaim (special dismal-map))
-(eval-when (load))
-
-;;; this assumes emacspeak-prefix is C-e
-;;; and function-key-prefix is M-[
-(add-hook 'dis-mode-hooks
-          (function
-           (lambda nil
-             (declare (special dismal-map emacspeak-prefix))
-             (local-unset-key "\M-[")
-             (local-unset-key emacspeak-prefix)
-             (define-key dismal-map (concat emacspeak-prefix "e")
-               'dis-last-column)
-             (define-key dismal-map  "," 'emacspeak-dismal-display-cell-expression)
-             (define-key dismal-map  "."
-               'emacspeak-dismal-display-cell-value)
-             (define-key dismal-map "R"
-               'emacspeak-dismal-display-cell-with-row-header)
-             (define-key dismal-map "S"
-               'emacspeak-dismal-sheet-summarize)
-             (define-key dismal-map "C"
-               'emacspeak-dismal-display-cell-with-col-header)
-             (define-key dismal-map "\M-m"
-               'emacspeak-dismal-row-summarize)
-             (define-key dismal-map '[up]
-               'emacspeak-dismal-backward-row-and-summarize)
-             (define-key dismal-map '[down]
-               'emacspeak-dismal-forward-row-and-summarize)
-             (define-key dismal-map '[left]
-               'emacspeak-dismal-backward-col-and-summarize)
-             (define-key dismal-map '[right]
-               'emacspeak-dismal-forward-col-and-summarize)
-             )))
+(add-hook
+ 'dis-mode-hooks
+ #'(lambda nil
+     (cl-declare (special dismal-map emacspeak-prefix))
+     (local-unset-key "\M-[")
+     (local-unset-key emacspeak-prefix)
+     (define-key dismal-map emacspeak-prefix 'emacspeak-prefix-command)
+     (define-key dismal-map (concat emacspeak-prefix "e")
+       'dis-last-column)
+     (define-key dismal-map  "," 'emacspeak-dismal-display-cell-expression)
+     (define-key dismal-map  "." 'emacspeak-dismal-display-cell-value)
+     (define-key dismal-map "R" 'emacspeak-dismal-display-cell-with-row-header)
+     (define-key dismal-map "S" 'emacspeak-dismal-sheet-summarize)
+     (define-key dismal-map "C" 'emacspeak-dismal-display-cell-with-col-header)
+     (define-key dismal-map "\M-m" 'emacspeak-dismal-row-summarize)
+     (define-key dismal-map '[up] 'emacspeak-dismal-backward-row-and-summarize)
+     (define-key dismal-map '[down] 'emacspeak-dismal-forward-row-and-summarize)
+     (define-key dismal-map '[left] 'emacspeak-dismal-backward-col-and-summarize)
+     (define-key dismal-map '[right] 'emacspeak-dismal-forward-col-and-summarize)))
 
 ;;}}}
 ;;{{{  Advice some commands. 
