@@ -1,5 +1,5 @@
-;;; emacspeak-ecb.el --- speech-enable Emacs Class Browser
-;;; $Id: emacspeak-ecb.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
+;;; emacspeak-ecb.el --- speech-enable Emacs Class Browser  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for speech-enabling Emacs
 ;;; Class Browser
@@ -17,7 +17,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -38,59 +38,76 @@
 
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-
-;;{{{ required modules
-
-(require 'emacspeak-preamble)
-;;}}}
 ;;{{{  Introduction:
 
+;;; Commentary:
 ;;; The ECB is an Emacs Class Browser.
 ;;; This module speech-enables ECB
+;;; Code:
+
+;;}}}
+;;{{{ required modules
+
+(cl-declaim  (optimize  (safety 0) (speed 3)))
+(require 'emacspeak-preamble)
+(eval-when-compile
+  (let ((inhibit-message  t))
+    (require 'ecb "ecb" 'no-error))
+  (require 'tree-buffer "tree-buffer" 'no-error))
+;;}}}
+;;{{{ Forward Declarations:
+
+(declare-function tree-node->expandable "tree-buffer" (cl-x))
+(declare-function tree-node->expanded "tree-buffer" (cl-x))
+(declare-function ecb-goto-window-methods "ecb-method-browser" nil)
+(declare-function ecb-goto-window-directories "ecb-file-browser" nil)
+(declare-function ecb-goto-window-history "ecb-file-browser" nil)
+(declare-function ecb-goto-window-sources "ecb-file-browser" nil)
 
 ;;}}}
 ;;{{{  advice interactive commands
 
 (defadvice ecb-activate (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice ecb-cancel-dialog (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice ecb-show-help (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'help)
     (emacspeak-speak-mode-line)))
 
-(loop for f in 
-      '(
-        ecb-nav-goto-next
-        ecb-nav-goto-previous
-        ecb-goto-window-compilation
-        ecb-goto-window-directories 
-        ecb-goto-window-sources 
-        ecb-goto-window-methods 
-        ecb-goto-window-history 
-        ecb-goto-window-edit1 
-        ecb-goto-window-edit2 )
-      do
-      (eval 
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (ems-interactive-p )
-            (emacspeak-speak-line)
-            (emacspeak-auditory-icon 'select-object)))))
+(cl-loop
+ for f in 
+ '(
+   ecb-nav-goto-next
+   ecb-nav-goto-previous
+   ecb-goto-window-compilation
+   ecb-goto-window-directories 
+   ecb-goto-window-sources 
+   ecb-goto-window-methods 
+   ecb-goto-window-history 
+   ecb-goto-window-edit1 
+   ecb-goto-window-edit2)
+ do
+ (eval 
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Provide auditory feedback."
+     (when (ems-interactive-p)
+       (emacspeak-speak-line)
+       (emacspeak-auditory-icon 'select-object)))))
 
 (defadvice ecb-select-ecb-frame (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'select-object)))
 
@@ -104,7 +121,7 @@
 (defun emacspeak-ecb-tree-backspace ()
   "Back up during incremental search in tree buffers."
   (interactive)
-  (declare (special tree-buffer-incr-searchpattern))
+  (cl-declare (special tree-buffer-incr-searchpattern))
   ;; reduce by one from the end
   (setq tree-buffer-incr-searchpattern
         (substring tree-buffer-incr-searchpattern
@@ -117,33 +134,10 @@
 (defun emacspeak-ecb-tree-clear ()
   "Clear search pattern during incremental search in tree buffers."
   (interactive)
-  (declare (special tree-buffer-incr-searchpattern))  
+  (cl-declare (special tree-buffer-incr-searchpattern))  
   (setq tree-buffer-incr-searchpattern "")
   (dtk-speak "Cleared search pattern."))
 
-(defun emacspeak-ecb-tree-expand-common-prefix ()
-  "Expand to longest common prefix in tree buffer."
-  (interactive)
-  (declare (special tree-buffer-incr-searchpattern
-                    tree-buffer-incr-search
-                    tree-buffer-root))
-  ;; expand to the max. common prefix
-  (let* ((node-name-list (tree-node-get-all-visible-node-names
-                          tree-buffer-root))
-         (common-prefix (tree-buffer-find-common-substring
-                         node-name-list tree-buffer-incr-searchpattern
-                         (if (equal tree-buffer-incr-search 'prefix) t))))
-    (if (stringp common-prefix)
-        (setq tree-buffer-incr-searchpattern
-              common-prefix))
-    (end-of-line)
-    (emacspeak-speak-line)))
-
-(defun emacspeak-ecb-tree-shift-return ()
-  "Do shift return in ECB tree browser."
-  (interactive)
-  (tree-buffer-return-pressed 'shift nil))
-
 (defadvice tree-buffer-create (after emacspeak pre act comp)
   "Fixes up keybindings so incremental tree search is
 available."
@@ -153,23 +147,20 @@ available."
                                  'tree-buffer-incremental-node-search
                                  tree-buffer-key-map
                                  global-map))
-    (define-key tree-buffer-key-map "\M-\C-m"
-      'emacspeak-ecb-tree-shift-return)
     (define-key tree-buffer-key-map "\d"
       'emacspeak-ecb-tree-backspace)
     (define-key tree-buffer-key-map '[delete]
       'emacspeak-ecb-tree-backspace)
     (define-key tree-buffer-key-map '[home]
       'emacspeak-ecb-tree-clear)
-    (define-key tree-buffer-key-map '[end]
-      'emacspeak-ecb-tree-expand-common-prefix)))
+    ))
 
 (defadvice tree-buffer-incremental-node-search 
-  (around emacspeak pre act comp)
+    (around emacspeak pre act comp)
   "Track search and provide appropriate auditory feedback."
   
   (cond
-   ((ems-interactive-p )
+   ((ems-interactive-p)
     (let ((start (point))
           (beg nil)
           (end nil))
@@ -184,10 +175,10 @@ available."
             (backward-char 1)
             (search-forward tree-buffer-incr-searchpattern)
             (setq end (point))
-            (ems-modify-buffer-safely
-             (ems-set-personality-temporarily
-              beg end   voice-bolden
-              (emacspeak-speak-line)))
+            (with-silent-modifications
+              (ems-set-personality-temporarily
+               beg end   voice-bolden
+               (emacspeak-speak-line)))
             (emacspeak-auditory-icon 'search-hit))))
        (t (emacspeak-auditory-icon 'search-miss)))))
    (t ad-do-it))
@@ -195,14 +186,18 @@ available."
 
 (defadvice tree-buffer-select (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
+(defun tree-node-is-expanded (node)
+  "Check if node is expanded."
+  (or (not (tree-node->expandable node))
+      (tree-node->expanded node)))
 
 (defadvice tree-node-toggle-expanded (after emacspeak pre
                                             act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (let ((node (ad-get-arg 0))) ;; note that logic is reversed
       (cond
        ((tree-node-is-expanded node)
@@ -211,7 +206,7 @@ available."
 
 (defadvice tree-buffer-update (after emacspeak pre act comp)
   "Provide context speech feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-speak-line)))
 
 (defadvice tree-buffer-nolog-message (after emacspeak pre
@@ -221,19 +216,19 @@ available."
 
 (defadvice tree-buffer-arrow-pressed (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)
     (emacspeak-speak-line)))
 
 (defadvice tree-buffer-tab-pressed (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)
     (emacspeak-speak-line)))
 
 (defadvice tree-buffer-return-pressed (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)
     (emacspeak-speak-line)))
 
@@ -241,9 +236,9 @@ available."
                                                   act comp)
   "When on the console, always use TMM."
   (cond
-   ((and (ems-interactive-p )
+   ((and (ems-interactive-p)
          (not (display-graphic-p)))
-    (tree-buffer-show-menu-keyboard 'use-tmm)    )
+    (tree-buffer-show-menu-keyboard 'use-tmm))
    (t ad-do-it)))
 
 ;;}}}
@@ -287,7 +282,7 @@ available."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
