@@ -1,5 +1,5 @@
-;;; emacspeak-emms.el --- Speech-enable EMMS Multimedia UI
-;;; $Id: emacspeak-emms.el 7425 2011-11-22 01:55:17Z tv.raman.tv $
+;;; emacspeak-emms.el --- Speech-enable EMMS Multimedia UI  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech-enable EMMS
 ;;; Keywords: Emacspeak, Multimedia
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995--2004, 2011 T. V. Raman <raman@cs.cornell.edu>
+;;;Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -53,8 +53,9 @@
 ;;}}}
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-
+(require 'emms "emms" 'no-error)
 ;;}}}
 ;;{{{ module emms:
 
@@ -62,53 +63,59 @@
   "Speak current track."
   (interactive)
   (message
-   (cdr (assq 'name (emms-playlist-current-track)))))
+   (cdr (assq 'name (emms-playlist-current-selected-track)))))
 
-(loop for f in
-      '(emms-next emms-next-noerror emms-previous)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Speak track name."
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'select-object)))))
+(cl-loop for f in
+         '(emms-next emms-next-noerror emms-previous)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Speak track name."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'select-object)))))
 
 ;;; these commands should not be made to talk since that would  interferes
 ;;; with real work.
-(loop for f in
-      '(emms-start emms-stop emms-sort
-                   emms-shuffle emms-random)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory icon."
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'select-object)))))
+(cl-loop for f in
+         '(emms-start emms-stop emms-sort
+                      emms-shuffle emms-random)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Provide auditory icon."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'select-object)))))
 
-(loop for f in
-      '(emms-playlist-first emms-playlist-last
-                            emms-playlist-mode-first emms-playlist-mode-last)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'large-movement)
-            (emacspeak-speak-line)))))
-(loop for f in
-      '(emms-browser emms-browser-next-filter
-                     emms-browser-previous-filter)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (interactive-p)
-            (emacspeak-speak-mode-line)
-            (emacspeak-auditory-icon 'open-object)))))
+(cl-loop for f in
+         '(emms-playlist-first emms-playlist-last
+                               emms-playlist-mode-first emms-playlist-mode-last)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Provide auditory feedback."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'large-movement)
+               (emacspeak-speak-line)))))
+(cl-loop for f in
+         '(emms-browser emms-browser-next-filter
+                        emms-browser-previous-filter)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Provide auditory feedback."
+             (when (ems-interactive-p)
+               (emacspeak-speak-mode-line)
+               (emacspeak-auditory-icon 'open-object)))))
+
+(defadvice emms-browser-bury-buffer (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (ems-interactive-p)
+    (emacspeak-speak-mode-line)
+    (emacspeak-auditory-icon 'close-object)))
 
 ;;}}}
 ;;{{{ Module emms-streaming:
-(declaim (special emms-stream-mode-map))
+(cl-declaim (special emms-stream-mode-map))
 (defadvice emms-stream-mode (after emacspeak pre act comp)
   "Update keymaps."
   (define-key emms-stream-mode-map "\C-e"
@@ -117,41 +124,41 @@
 (defadvice emms-stream-delete-bookmark (after emacspeak pre act
                                               comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-line)))
 
 (defadvice emms-stream-save-bookmarks-file (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)
     (message "Saved stream bookmarks.")))
 
-(loop for f in
-      '(emms-streams emms-stream-quit
-                     emms-stream-popup emms-stream-popup-revert
-                     emms-playlist-mode-go
-                     )
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (interactive-p)
-            (emacspeak-speak-mode-line)))))
+(cl-loop for f in
+         '(emms-streams emms-stream-quit
+                        emms-stream-popup emms-stream-popup-revert
+                        emms-playlist-mode-go
+                        )
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Provide auditory feedback."
+             (when (ems-interactive-p)
+               (emacspeak-speak-mode-line)))))
 
-(loop for f in
-      '(emms-stream-next-line emms-stream-previous-line)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (interactive-p)
-            (emacspeak-speak-line)))))
+(cl-loop for f in
+         '(emms-stream-next-line emms-stream-previous-line)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Provide auditory feedback."
+             (when (ems-interactive-p)
+               (emacspeak-speak-line)))))
 (defadvice emms-playlist-mode-bury-buffer (after emacspeak pre act)
   "Announce the buffer that becomes current."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
-    (emacspeak-speak-mode-line )))
+    (emacspeak-speak-mode-line)))
 
 ;;}}}
 ;;{{{ silence chatter from info
@@ -160,8 +167,8 @@
                                                      pre act
                                                      comp)
   "Silence messages."
-  (let ((emacspeak-speak-messages nil))
-    ad-do-it))
+  (ems-with-messages-silenced
+   ad-do-it))
 
 ;;}}}
 ;;{{{ pause/resume if needed
@@ -170,7 +177,7 @@
 (defun emacspeak-emms-pause-or-resume ()
   "Pause/resume if emms is running. For use  in
 emacspeak-silence-hook."
-  (declare (special emms-player-playing-p))
+  (cl-declare (special emms-player-playing-p))
   (when (and (boundp 'emms-player-playing-p)
              (not (null emms-player-playing-p)))
     (emms-player-pause)))
