@@ -1,5 +1,5 @@
-;;; emacspeak-erc.el --- speech-enable erc irc client
-;;; $Id: emacspeak-erc.el 8264 2013-03-29 00:48:04Z tv.raman.tv $
+;;; emacspeak-erc.el --- speech-enable erc irc client  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for speech-enabling erc.el
 ;;; Keywords: Emacspeak, erc
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -50,11 +50,14 @@
 
 ;;}}}
 ;;{{{ required modules
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
+(require 'erc)
 ;;}}}
 ;;{{{  variables
 
-(declaim (special emacspeak-sounds-directory))
+(cl-declaim (special emacspeak-sounds-directory))
 
 ;;}}}
 ;;{{{ personalities 
@@ -64,7 +67,7 @@
   :group 'emacspeak
   :prefix "emacspeak-erc-")
 
-(defcustom emacspeak-erc-ignore-notices nil
+(defcustom emacspeak-erc-ignore-notices t
   "Set to T if you dont want to see notification  messages from the
 server."
   :type 'boolean
@@ -91,30 +94,30 @@ server."
 
 ;;}}}
 ;;{{{ advice interactive commands
-(declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
+(cl-declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
 (emacspeak-pronounce-augment-pronunciations 'erc-mode
                                             emacspeak-pronounce-internet-smileys-pronunciations)
 
 (defadvice erc-mode (after emacspeak pre act comp)
   "Turn on voice lock mode."
-  (declare (special voice-lock-mode))
+  (cl-declare (special voice-lock-mode))
   (emacspeak-pronounce-refresh-pronunciations)
   (setq voice-lock-mode t))
 
 (defadvice erc-select (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 (defadvice erc-send-current-line (after emacspeak pre act
                                         comp)
   "Provide auditory icon."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)))
 (defadvice erc-send-paragraph (after emacspeak pre act
                                      comp)
   "Provide auditory icon."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'paragraph)))
 
 ;;}}}
@@ -142,7 +145,7 @@ spoken.")
   :type 'string
   :group 'emacspeak-erc)
 
-(defsubst emacspeak-erc-read-person (action)
+(defun emacspeak-erc-read-person (action)
   "Helper to prompt for and read person in ERC."
   (read-from-minibuffer
    (format "%s person" action)
@@ -163,11 +166,10 @@ Optional interactive prefix  arg defines a pronunciation that
    (list
     (emacspeak-erc-read-person "Add ")
     current-prefix-arg))
-  (declare (special emacspeak-erc-people-to-monitor))
+  (cl-declare (special emacspeak-erc-people-to-monitor))
   (unless (eq major-mode 'erc-mode)
     (error "Not in an ERC buffer."))
-  (pushnew name emacspeak-erc-people-to-monitor
-           :test #'string-equal)
+  (cl-pushnew name emacspeak-erc-people-to-monitor :test #'string-equal)
   (when quiten-pronunciation
     (emacspeak-pronounce-add-buffer-local-dictionary-entry name ""))
   (emacspeak-auditory-icon 'select-object)
@@ -180,11 +182,11 @@ Optional interactive prefix  arg defines a pronunciation that
   (interactive
    (list
     (emacspeak-erc-read-person "Delete ")))
-  (declare (special emacspeak-erc-people-to-monitor))
+  (cl-declare (special emacspeak-erc-people-to-monitor))
   (unless (eq major-mode 'erc-mode)
     (error "Not in an ERC buffer."))
   (setq emacspeak-erc-people-to-monitor
-        (remove-if
+        (cl-remove-if
          (function
           (lambda (x)
             (string-equal x name)))
@@ -200,21 +202,21 @@ Optional interactive prefix  arg defines a pronunciation that
 
 (make-variable-buffer-local 'emacspeak-erc-speak-all-participants)
 
-(defun emacspeak-erc-compute-message (string buffer)
+(defun emacspeak-erc-compute-message (string _buffer)
   "Uses environment of buffer to decide what message to
 display. String is the original message."
-  (declare (special emacspeak-erc-people-to-monitor
-                    emacspeak-erc-my-nick
-                    emacspeak-erc-speak-all-participants
-                    emacspeak-erc-monitor-my-messages))
-  (let ((who-from (car (split-string string )))
+  (cl-declare (special emacspeak-erc-people-to-monitor
+                       emacspeak-erc-my-nick
+                       emacspeak-erc-speak-all-participants
+                       emacspeak-erc-monitor-my-messages))
+  (let ((who-from (car (split-string string)))
         (case-fold-search t))
     (cond
      (emacspeak-erc-speak-all-participants string)
      ((and
        (not (string-match "^\\*\\*\\*" who-from))
        emacspeak-erc-people-to-monitor
-       (find
+       (cl-find
         who-from
         emacspeak-erc-people-to-monitor
         :test #'string-equal))
@@ -236,11 +238,11 @@ set the current local value to the result.")
 (defadvice erc-display-line-buffer  (after emacspeak pre act
                                            comp)
   "Speech-enable ERC."
-  (declare (special emacspeak-erc-room-monitor
-                    emacspeak-erc-monitor-my-messages
-                    emacspeak-erc-my-nick))
-  (let ( (buffer (ad-get-arg 1))
-         (case-fold-search t))
+  (cl-declare (special emacspeak-erc-room-monitor
+                       emacspeak-erc-monitor-my-messages
+                       emacspeak-erc-my-nick))
+  (let ((buffer (ad-get-arg 1))
+        (case-fold-search t))
     (with-current-buffer  buffer
       (when (and emacspeak-erc-room-monitor
                  emacspeak-erc-monitor-my-messages)
@@ -255,21 +257,20 @@ set the current local value to the result.")
 
 (defadvice erc-display-line-1  (after emacspeak pre act comp)
   "Speech-enable ERC."
-  (declare (special emacspeak-erc-room-monitor
-                    emacspeak-erc-monitor-my-messages
-                    emacspeak-erc-my-nick))
-  (let ( (buffer (ad-get-arg 1))
-         (case-fold-search t))
-    (save-excursion
+  (cl-declare (special emacspeak-erc-room-monitor
+                       emacspeak-erc-monitor-my-messages
+                       emacspeak-erc-my-nick))
+  (let ((buffer (ad-get-arg 1))
+        (case-fold-search t))
+    (save-current-buffer
       (set-buffer buffer)
       (when (and emacspeak-erc-room-monitor
                  emacspeak-erc-monitor-my-messages)
-        (let ((emacspeak-speak-messages nil)
-              (msg (emacspeak-erc-compute-message (ad-get-arg 0)
+        (let ((msg (emacspeak-erc-compute-message (ad-get-arg 0)
                                                   buffer)))
           (when msg
             (emacspeak-auditory-icon 'progress)
-            (message msg)
+            (dtk-speak-and-echo (format "%s" msg))
             (tts-with-punctuations dtk-punctuation-mode
                                    (dtk-speak  msg))))))))
 
@@ -300,12 +301,12 @@ set the current local value to the result.")
   "Ignore notices from server is emacspeak-erc-ignore-notices it set."
   ad-do-it
   (cond
-   ((not emacspeak-erc-ignore-notices ) ad-return-value)
+   ((not emacspeak-erc-ignore-notices) ad-return-value)
    (t " ")))
 
 ;;}}}
 ;;{{{ define emacspeak keys
-(declaim (special erc-mode-map))
+(cl-declaim (special erc-mode-map))
 (define-key erc-mode-map "\C-c "
   'emacspeak-erc-toggle-speak-all-participants)
 (define-key erc-mode-map "\C-cm"
@@ -327,15 +328,15 @@ set the current local value to the result.")
   (let ((fields (split-string pattern "-")))
     (format " %s for %s off %s overs with %s maidens "
             (cond
-             ((string-equal "0" (fourth fields)) 
+             ((string-equal "0" (cl-fourth fields)) 
               "none")
-             (t (fourth fields)))
-            (third fields)
-            (first fields)
+             (t (cl-fourth fields)))
+            (cl-third fields)
+            (cl-first fields)
             (cond
-             ((string-equal "0" (second fields)) 
+             ((string-equal "0" (cl-second fields)) 
               "no")
-             (t (second fields))))))
+             (t (cl-second fields))))))
 
 (defvar emacspeak-erc-cricket-4-6-pattern
   " [0-9]+x\[46]"
@@ -391,7 +392,7 @@ set the current local value to the result.")
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
