@@ -1,5 +1,5 @@
-;;; emacspeak-eshell.el --- Speech-enable EShell - Emacs Shell
-;;; $Id: emacspeak-eshell.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
+;;; emacspeak-eshell.el --- Speech-enable EShell - Emacs Shell  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:   Speech-enable EShell
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -50,6 +50,7 @@
 ;;}}}
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'esh-arg)
 
@@ -59,7 +60,7 @@
 ;;; Play an auditory icon as you display the prompt
 (defun emacspeak-eshell-prompt-function ()
   "Play auditory icon for prompt."
-  (declare (special eshell-last-command-status))
+  (cl-declare (special eshell-last-command-status))
   (cond
    ((= 0 eshell-last-command-status)
     (emacspeak-auditory-icon 'item))
@@ -71,8 +72,8 @@
 
 (defun emacspeak-eshell-speak-output  ()
   "Speak eshell output."
-  (declare (special eshell-last-input-end eshell-last-output-end
-                    eshell-last-output-start))
+  (cl-declare (special eshell-last-input-end eshell-last-output-end
+                       eshell-last-output-start))
   (emacspeak-speak-region eshell-last-input-end eshell-last-output-end))
 
 (add-hook 
@@ -83,33 +84,35 @@
 ;;}}}
 ;;{{{  Advice top-level EShell
 
-(defadvice eshell (after emacspeak pre act )
+(defadvice eshell (after emacspeak pre act)
   "Announce switching to shell mode.
 Provide an auditory icon if possible."
-  (when (interactive-p)
-    (emacspeak-auditory-icon 'select-object )
-    (emacspeak-setup-programming-mode)
-    (emacspeak-dtk-sync)
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'open-object)
+    (dtk-set-punctuations 'all)
+    (or dtk-split-caps
+        (dtk-toggle-split-caps))
+    (emacspeak-pronounce-refresh-pronunciations)
     (emacspeak-speak-line)))
 
 ;;}}}
 ;;{{{ advice em-hist
 
-(loop for f in
-      '(
-        eshell-next-input eshell-previous-input
-                          eshell-next-matching-input eshell-previous-matching-input
-                          eshell-next-matching-input-from-input eshell-previous-matching-input-from-input)
-      do
-      (eval
-       `(defadvice ,f (after  emacspeak pre act comp)
-          "Speak selected command."
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'select-object)
-            (save-excursion
-              (beginning-of-line)
-              (eshell-skip-prompt)
-              (emacspeak-speak-line 1))))))
+(cl-loop for f in
+         '(
+           eshell-next-input eshell-previous-input
+           eshell-next-matching-input eshell-previous-matching-input
+           eshell-next-matching-input-from-input eshell-previous-matching-input-from-input)
+         do
+         (eval
+          `(defadvice ,f (after  emacspeak pre act comp)
+             "Speak selected command."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'select-object)
+               (save-excursion
+                 (beginning-of-line)
+                 (eshell-skip-prompt)
+                 (emacspeak-speak-line 1))))))
 
 ;;}}}
 ;;{{{  advice em-ls
@@ -160,39 +163,39 @@ personalities."
 ;;}}}
 ;;{{{ Advice em-prompt
 
-(loop for f in
-      '(
-        eshell-next-prompt eshell-previous-prompt
-                           eshell-forward-matching-input  eshell-backward-matching-input)
-      do
-      (eval
-       `(defadvice ,f (after  emacspeak pre act comp)
-          "Speak selected command."
-          (when (interactive-p)
-            (let ((emacspeak-speak-messages nil))
-              (emacspeak-auditory-icon 'select-object)
-              (emacspeak-speak-line 1))))))
+(cl-loop for f in
+         '(
+           eshell-next-prompt eshell-previous-prompt
+           eshell-forward-matching-input  eshell-backward-matching-input)
+         do
+         (eval
+          `(defadvice ,f (after  emacspeak pre act comp)
+             "Speak selected command."
+             (when (ems-interactive-p)
+               (let ((emacspeak-speak-messages nil))
+                 (emacspeak-auditory-icon 'select-object)
+                 (emacspeak-speak-line 1))))))
 
 ;;}}}
 ;;{{{  advice esh-arg
 
-(loop for f in
-      '(
-        eshell-insert-buffer-name
-        eshell-insert-process
-        eshell-insert-envvar)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Speak output."
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'select-object)
-            (emacspeak-speak-line)))))
+(cl-loop for f in
+         '(
+           eshell-insert-buffer-name
+           eshell-insert-process
+           eshell-insert-envvar)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Speak output."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'select-object)
+               (emacspeak-speak-line)))))
 
 (defadvice eshell-insert-process (after emacspeak pre
                                         act comp)
   "Speak output."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
@@ -202,11 +205,11 @@ personalities."
 (defadvice eshell-delchar-or-maybe-eof (around emacspeak pre act)
   "Speak character you're deleting."
   (cond
-   ((interactive-p )
+   ((ems-interactive-p)
     (cond
      ((= (point) (point-max))
       (message "Sending EOF to comint process"))
-     (t (dtk-tone 500 30 'force)
+     (t (dtk-tone 500 100 'force)
         (emacspeak-speak-char t)))
     ad-do-it)
    (t ad-do-it))
@@ -215,40 +218,40 @@ personalities."
 (defadvice eshell-delete-backward-char (around emacspeak pre act)
   "Speak character you're deleting."
   (cond
-   ((interactive-p )
-    (dtk-tone 500 30 'force)
-    (emacspeak-speak-this-char (preceding-char ))
+   ((ems-interactive-p)
+    (dtk-tone 500 100 'force)
+    (emacspeak-speak-this-char (preceding-char))
     ad-do-it)
    (t ad-do-it))
   ad-return-value)
 
 (defadvice eshell-show-output (after emacspeak pre act comp)
   "Speak output."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-auditory-icon 'large-movement)
       (emacspeak-speak-region (point) (mark)))))
 (defadvice eshell-mark-output (after emacspeak pre act comp)
   "Speak output."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-auditory-icon 'mark-object)
       (emacspeak-speak-line))))
 (defadvice eshell-kill-output (after emacspeak pre act comp)
   "Produce auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (message "Flushed output")))
 
-(defadvice eshell-kill-input (before emacspeak pre act )
+(defadvice eshell-kill-input (before emacspeak pre act)
   "Provide spoken feedback."
-  (when (interactive-p)
-    (emacspeak-auditory-icon 'delete-object )
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-line)))
 
 (defadvice eshell-toggle (after emacspeak pre act comp)
   "Provide spoken context feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (cond
      ((eq major-mode 'eshell-mode)
       (emacspeak-setup-programming-mode)
@@ -257,13 +260,66 @@ personalities."
     (emacspeak-auditory-icon 'select-object)))
 (defadvice eshell-toggle-cd (after emacspeak pre act comp)
   "Provide spoken context feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (cond
      ((eq major-mode 'eshell-mode)
       (emacspeak-speak-line))
      (t (emacspeak-speak-mode-line)))
     (emacspeak-auditory-icon 'select-object)))
 
+;;}}}
+;;{{{Additional Commands To Enable: 
+
+(cl-loop
+ for f in
+ '(eshell-forward-argument eshell-backward-argument eshell-bol)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "provide auditory feedback."
+     (when
+         (ems-interactive-p)
+       (let ((emacspeak-show-point t))
+         (emacspeak-speak-line)
+         (emacspeak-auditory-icon 'large-movement))))))
+
+(cl-loop
+ for f in
+ '(eshell-pcomplete eshell-complete-lisp-symbol)
+ do
+ (eval
+  `(defadvice ,f (around emacspeak pre act comp)
+     "Say what you completed."
+     (ems-with-messages-silenced
+      (let ((prior (save-excursion (skip-syntax-backward "^ >") (point))))
+        ad-do-it
+        (if (> (point) prior)
+            (tts-with-punctuations
+             'all
+             (dtk-speak
+              (buffer-substring prior (point))))
+          (emacspeak-speak-completions-if-available))
+        ad-return-value)))))
+
+(defadvice eshell-copy-old-input (after emacspeak pre act comp)
+  "Speak what was inserted."
+  (when (ems-interactive-p)
+    (let ((start
+           (save-excursion
+             (eshell-bol)
+             (point))))
+      (emacspeak-auditory-icon 'yank-object)
+      (emacspeak-speak-region start (point)))))
+(defadvice eshell-get-next-from-history (after emacspeak pre act comp)
+  "Speak what was inserted."
+  (when (ems-interactive-p)
+    (let ((start
+           (save-excursion
+             (eshell-bol)
+             (point))))
+      (emacspeak-auditory-icon 'yank-object)
+      (emacspeak-speak-region start (point)))))
+
 ;;}}}
 
 (provide 'emacspeak-eshell)
