@@ -1,5 +1,5 @@
-;;; emacspeak-filtertext.el --- Utilities to filter text
-;;; $Id: emacspeak-filtertext.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-filtertext.el --- Utilities to filter text  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:   Implement text filters 
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,10 +40,11 @@
 
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
-
+;;; Commentary:
 ;;; It is often useful  to view the results of filtering
 ;;; large amounts of text.;;; Typically you do this with
 ;;; various combinations of grep and friends.
@@ -58,13 +59,13 @@
 ;;; unfiltered text
 ;;; D: Provides commands for saving results from
 ;;; intermediate filters.
-
+;;; Code:
 ;;}}}
 ;;{{{  structures 
 
-(defstruct (emacspeak-filtertext
-            (:constructor
-             emacspeak-filtertext-constructor))
+(cl-defstruct (emacspeak-filtertext
+               (:constructor
+                emacspeak-filtertext-constructor))
   text                                  ;original text
   filters                               ;chain of filters applied 
   )
@@ -80,11 +81,11 @@
   "FilterText mode"
   "Major mode for FilterText interaction. \n\n
 \\{emacspeak-filtertext-mode-map}")
-(declare (special emacspeak-filtertext-mode-map))
+(cl-declare (special emacspeak-filtertext-mode-map))
 (define-key emacspeak-filtertext-mode-map "=" 'keep-lines)
 (define-key emacspeak-filtertext-mode-map "^" 'flush-lines)
 (define-key emacspeak-filtertext-mode-map "r"
-  'emacspeak-filtertext-revert )
+  'emacspeak-filtertext-revert)
 
 ;;}}}
 ;;{{{ Interactive commands 
@@ -93,12 +94,12 @@
   "Copy over text in region to special filtertext buffer in
 preparation for interactively filtering text. "
   (interactive "r")
-  (declare (special emacspeak-filtertext-info
-                    case-fold-search))
+  (cl-declare (special emacspeak-filtertext-info
+                       case-fold-search))
   (let ((this (buffer-substring-no-properties start end))
         (buffer (get-buffer-create
                  (format "filter-%s" (buffer-name)))))
-    (save-excursion
+    (save-current-buffer
       (set-buffer buffer)
       (setq case-fold-search t)
       (erase-buffer)
@@ -115,7 +116,7 @@ preparation for interactively filtering text. "
 (defun emacspeak-filtertext-revert ()
   "Revert to original text."
   (interactive)
-  (declare (special emacspeak-filtertext-info))
+  (cl-declare (special emacspeak-filtertext-info))
   (unless (eq  major-mode 'emacspeak-filtertext-mode)
     (error "Not in filter text mode."))
   (when emacspeak-filtertext-info
@@ -130,7 +131,7 @@ preparation for interactively filtering text. "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
