@@ -1,5 +1,5 @@
-;;; emacspeak-find-func.el --- Speech enable emacs' code finder
-;;; $Id: emacspeak-find-func.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-find-func.el --- Speech enable emacs' code finder  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable find-func
 ;;; Keywords: Emacspeak, find-func
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2018, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -46,6 +46,7 @@
 
 ;;}}}
 ;;{{{ requires
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
 ;;}}}
@@ -58,16 +59,14 @@
     find-function-on-key)
   "Commands to speech enable")
 
-(loop for f in emacspeak-find-func-commands
-      do
-      (eval
-       `(defadvice ,f  (after emacspeak pre act comp)
-          "Speak current line"
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'open-object)
-            (emacspeak-dtk-sync)
-            (dtk-speak
-             (format "Found %s" (ad-get-arg 0)))))))
+(cl-loop for f in emacspeak-find-func-commands
+         do
+         (eval
+          `(defadvice ,f  (after emacspeak pre act comp)
+             "Speak current line"
+             (when  (ems-interactive-p)
+               (emacspeak-auditory-icon 'open-object)
+               (dtk-speak (format "Found %s" (ad-get-arg 0)))))))
 
 ;;}}}
 
