@@ -1,5 +1,5 @@
-;;; emacspeak-generic.el --- Speech enable  generic modes
-;;; $Id: emacspeak-generic.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-generic.el --- Speech enable  generic modes  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable generic
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,6 +40,7 @@
 
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
@@ -58,13 +59,13 @@
 
 ;;}}}
 ;;{{{  generic setup
-(loop for mode in generic-mode-list
-      do
-      (when (functionp mode)
-        (eval
-         `(defadvice ,mode (after emacspeak pre act comp)
-            "Setup Emacspeak programming mode hooks."
-            (emacspeak-setup-programming-mode)))))
+(cl-loop for mode in generic-mode-list
+         do
+         (when (functionp mode)
+           (eval
+            `(defadvice ,mode (after emacspeak pre act comp)
+               "Setup Emacspeak programming mode hooks."
+               (emacspeak-setup-programming-mode)))))
 
 ;;}}}
 (provide 'emacspeak-generic)
