@@ -1,5 +1,5 @@
-;;; emacspeak-gomoku.el --- Speech enable the game of Gomoku
-;;; $Id: emacspeak-gomoku.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-gomoku.el --- Speech enable the game of Gomoku  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to gomoku
 ;;; Keywords: Emacspeak, Speak, Spoken Output, gomoku
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2011, T. V. Raman
+;;; Copyright (c) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,22 +40,23 @@
 
 ;;{{{  Required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'gomoku)
 ;;}}}
 ;;{{{  Introduction 
-
+;;; Commentary:
 ;;; Auditory interface to gomoku
-
+;;; Code:
 ;;}}}
 ;;{{{ helper functions
 
-(defsubst gomoku-point-x ()
+(defun gomoku-point-x ()
   (gomoku-index-to-x (gomoku-point-square)))
-(defsubst emacspeak-gomoku-cell-value (row column)
-  (declare (special gomoku-board))
+(defun emacspeak-gomoku-cell-value (row column)
+  (cl-declare (special gomoku-board))
   (aref  gomoku-board
-         (gomoku-xy-to-index column row )))
+         (gomoku-xy-to-index column row)))
 
 ;;}}}
 ;;{{{ Communicate state
@@ -76,7 +77,7 @@
    (format "%s %s %s"
            (gomoku-point-y)
            (gomoku-point-x)
-           (case (char-after (point))
+           (cl-case (char-after (point))
              (?X "x")
              (?. "-")
              (?O "0")))))
@@ -84,40 +85,40 @@
 (defun emacspeak-gomoku-show-current-row ()
   "Aurally display current row"
   (interactive)
-  (declare (special gomoku-board-width))
+  (cl-declare (special gomoku-board-width))
   (let ((row (gomoku-point-y))
         (values nil))
     (setq values
-          (loop for i from 1 to gomoku-board-width
-                collect 
-                (case (emacspeak-gomoku-cell-value row i )
-                  (0 "-")
-                  (1  "x")
-                  (6 "0"))))
+          (cl-loop for i from 1 to gomoku-board-width
+                   collect 
+                   (cl-case (emacspeak-gomoku-cell-value row i)
+                     (0 "-")
+                     (1  "x")
+                     (6 "0"))))
     (dtk-speak
      (apply 'concat values))))
 
 (defun emacspeak-gomoku-show-current-column ()
   "Aurally display current column"
   (interactive)
-  (declare (special gomoku-board-height))
+  (cl-declare (special gomoku-board-height))
   (let ((column (gomoku-point-x))
         (values nil))
     (setq values
-          (loop for i from 1 to gomoku-board-height
-                collect 
-                (case (emacspeak-gomoku-cell-value i column )
-                  (0 "-")
-                  (1  "x")
-                  (6 "0"))))
+          (cl-loop for i from 1 to gomoku-board-height
+                   collect 
+                   (cl-case (emacspeak-gomoku-cell-value i column)
+                     (0 "-")
+                     (1  "x")
+                     (6 "0"))))
     (dtk-speak
      (apply 'concat values))))
 
 (defun emacspeak-gomoku-show-current-positive-diagonal ()
   "Aurally display current positively sloped diagonal"
   (interactive)
-  (declare (special gomoku-board-height
-                    gomoku-board-width))
+  (cl-declare (special gomoku-board-height
+                       gomoku-board-width))
   (let ((row (gomoku-point-y))
         (column (gomoku-point-x))
         (diag-start-x nil)
@@ -130,25 +131,25 @@
      ((< row column)
       (setq diag-start-y  1
             diag-start-x (+ 1 (- column row))))
-     ((> row column )
+     ((> row column)
       (setq diag-start-x  1
             diag-start-y (+ 1 (- row column)))))
     (setq values
-          (loop for i from diag-start-y  to gomoku-board-height
-                and j from diag-start-x to gomoku-board-width 
-                collect
-                (case (emacspeak-gomoku-cell-value i j )
-                  (0 "-")
-                  (1  "x")
-                  (6 "0"))))
+          (cl-loop for i from diag-start-y  to gomoku-board-height
+                   and j from diag-start-x to gomoku-board-width 
+                   collect
+                   (cl-case (emacspeak-gomoku-cell-value i j)
+                     (0 "-")
+                     (1  "x")
+                     (6 "0"))))
     (dtk-speak
      (apply 'concat values))))
 
 (defun emacspeak-gomoku-show-current-negative-diagonal ()
   "Aurally display current negative sloped diagonal "
   (interactive)
-  (declare (special gomoku-board-height
-                    gomoku-board-width))
+  (cl-declare (special gomoku-board-height
+                       gomoku-board-width))
   (let ((row (gomoku-point-y))
         (column (gomoku-point-x))
         (diag-start-x nil)
@@ -164,26 +165,26 @@
             diag-start-x (- (+ column row) 1)))
      ((<  (+ 1 square-size) (+ row  column)) ; below major diag 
       (setq diag-start-x   (min gomoku-board-width
-                                (- (+ row column ) 1 )))
+                                (- (+ row column) 1)))
       (setq diag-start-y
             (- (+ row column) diag-start-x))))
     (setq values
-          (loop for i from diag-start-y  to gomoku-board-height
-                and j downfrom   diag-start-x  to 1 
-                collect
-                (case (emacspeak-gomoku-cell-value i j )
-                  (0 "-")
-                  (1  "x")
-                  (6 "0"))))
+          (cl-loop for i from diag-start-y  to gomoku-board-height
+                   and j downfrom   diag-start-x  to 1 
+                   collect
+                   (cl-case (emacspeak-gomoku-cell-value i j)
+                     (0 "-")
+                     (1  "x")
+                     (6 "0"))))
     (dtk-speak
      (apply 'concat values))))
 
 (defun emacspeak-gomoku-display-statistics ()
   "Display statistics from previous games"
   (interactive)
-  (declare (special gomoku-number-of-human-wins
-                    gomoku-number-of-emacs-wins
-                    gomoku-number-of-draws))
+  (cl-declare (special gomoku-number-of-human-wins
+                       gomoku-number-of-emacs-wins
+                       gomoku-number-of-draws))
   (message (format "Wins %d losses %d%s"
                    gomoku-number-of-human-wins
                    gomoku-number-of-emacs-wins
@@ -194,8 +195,8 @@
 (defun emacspeak-gomoku-speak-emacs-previous-move ()
   "Speak emacs' previous move"
   (interactive)
-  (declare (special gomoku-game-history))
-  (let ((square (car (first gomoku-game-history))))
+  (cl-declare (special gomoku-game-history))
+  (let ((square (car (cl-first gomoku-game-history))))
     (message "I last played on square %s %s"
              (gomoku-index-to-y square)
              (gomoku-index-to-x square))))
@@ -203,8 +204,8 @@
 (defun emacspeak-gomoku-speak-humans-previous-move ()
   "Speak human' previous move"
   (interactive)
-  (declare (special gomoku-game-history))
-  (let ((square (car (second gomoku-game-history))))
+  (cl-declare (special gomoku-game-history))
+  (let ((square (car (cl-second gomoku-game-history))))
     (message "You last played on square %s %s"
              (gomoku-index-to-y square)
              (gomoku-index-to-x square))))
@@ -212,7 +213,7 @@
 (defun emacspeak-gomoku-speak-number-of-moves ()
   "Speak number of moves so far"
   (interactive)
-  (declare (special gomoku-number-of-moves))
+  (cl-declare (special gomoku-number-of-moves))
   (message "%s moves in this game"
            gomoku-number-of-moves))
 
@@ -247,75 +248,75 @@
         'gomoku-move-sw)
   "Commands in gomoku that navigate the board")
 ;;; generated by:
-                                        ;(loop for command in
+                                        ;(cl-loop for command in
                                         ;      emacspeak-gomoku-navigation-commands
                                         ;      do
                                         ;      (insert
                                         ;       (format
                                         ;        "(defadvice %s  (after emacspeak pre act comp)
                                         ;              \"Provide auditory feedback\"
-                                        ;              (when (interactive-p)
+                                        ;              (when (ems-interactive-p)
                                         ;                (emacspeak-auditory-icon 'select-object)
                                         ;                (emacspeak-gomoku-speak-square)))\n\n"
                                         ;        command)))
 
 (defadvice gomoku-beginning-of-line  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-end-of-line  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-down  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-up  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-left  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-right  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-ne  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-nw  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-se  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-sw  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
@@ -328,34 +329,34 @@
 
 (defadvice gomoku-terminate-game (around emacspeak pre act comp)
   "Provide auditory feedback"
-  (declare (special emacspeak-last-message
-                    gomoku-number-of-moves))
+  (cl-declare (special emacspeak-last-message
+                       gomoku-number-of-moves))
   (let((result (ad-get-arg 0)))
     ad-do-it
     (dtk-speak
      (format "%s in %s moves  %s "
              result
              gomoku-number-of-moves
-             emacspeak-last-message ))
+             emacspeak-last-message))
     (sit-for 2))
   ad-return-value)
 
 (defadvice gomoku (after emacspeak pre act comp)
   "Speech enable gomoku"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-gomoku-setup-keys)))
 ;;}}}
 ;;{{{ keybindings
 
 (defun emacspeak-gomoku-setup-keys ()
   "Add additional keybindings"
-  (declare (special gomoku-mode-map))
-  (loop for key in (where-is-internal 'backward-char (list gomoku-mode-map))
-        do
-        (define-key gomoku-mode-map key 'gomoku-move-left))
-  (loop for key in (where-is-internal 'forward-char (list gomoku-mode-map))
-        do
-        (define-key gomoku-mode-map key 'gomoku-move-right))
+  (cl-declare (special gomoku-mode-map))
+  (cl-loop for key in (where-is-internal 'backward-char (list gomoku-mode-map))
+           do
+           (define-key gomoku-mode-map key 'gomoku-move-left))
+  (cl-loop for key in (where-is-internal 'forward-char (list gomoku-mode-map))
+           do
+           (define-key gomoku-mode-map key 'gomoku-move-right))
   (define-key gomoku-mode-map "\t"
     'emacspeak-gomoku-speak-emacs-previous-move)
   (define-key gomoku-mode-map "\M-\t"
@@ -385,7 +386,7 @@
 
 ;;}}}
 
-(provide 'emacspeak-gomoku )
+(provide 'emacspeak-gomoku)
 ;;{{{ end of file 
 
 ;;; local variables:
