@@ -1,5 +1,5 @@
-;;; emacspeak-mspools.el --- Speech enable MSpools -- Monitor multiple mail drops
-;;; $Id: emacspeak-mspools.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-mspools.el --- Speech enable MSpools -- Monitor multiple mail drops  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to mail spool tracker
 ;;; Keywords: Emacspeak, Speak, Spoken Output, mspools
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2011, T. V. Raman
+;;; Copyright (c) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,24 +40,25 @@
 
 ;;{{{  Required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction
-
-;;; Speech mspools --a package that lets you monitor
+;;; Commentary:
+;;; Speech-enable  mspools --a package that lets you monitor
 ;;; multiple maildrops
-
+;;; Code:
 ;;}}}
 ;;{{{ advice
 
 (defadvice mspools-show (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 (defadvice mspools-quit (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
@@ -67,8 +68,8 @@
   (emacspeak-speak-line))
 ;;}}}
 ;;{{{ keymaps
-(declaim (special mspools-mode-map))
-(eval-when (load)
+(cl-declaim (special mspools-mode-map))
+(cl-eval-when (load)
   (require 'emacspeak-keymap)
   )
 
