@@ -89,16 +89,16 @@
   (when (locate-library "package")
     (unless (locate-library "hydra") (package-install 'hydra))))
 (require 'emacspeak-hydra)
-(eval-when-compile
-  (require 'hideshow)
-  (require 'emacspeak-maths)
-  (require 'origami "origami" 'no-error)
-  (require 'smartparens "smartparens" 'no-error)
-  (require 'browse-kill-ring "browse-kill-ring" 'no-error)
-  (require 'hydra "hydra" 'no-error)
-  (require 'xbacklight)
-  (require 'view)
-  (require 'emacspeak-m-player))
+(require 'hideshow)
+(require 'emacspeak-maths nil 'no-error)
+(require 'org)
+(require 'origami "origami" 'no-error)
+(require 'smartparens "smartparens" 'no-error)
+(require 'browse-kill-ring "browse-kill-ring" 'no-error)
+(require 'hydra "hydra" 'no-error)
+(require 'xbacklight)
+(require 'view)
+(require 'emacspeak-m-player)
 (declare-function ido-ubiquitous-mode "ext:ido-completing-read+" (&optional arg))
 
 ;;}}}
