@@ -1,5 +1,5 @@
-;;; emacspeak-muse.el --- Speech-enable Muse
-;;; $Id: emacspeak-muse.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-muse.el --- Speech-enable Muse  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Speech-enable Muse
 ;;; Keywords: Emacspeak,  Audio Desktop Muse
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2018, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -48,6 +48,7 @@
 
 ;;; Code:
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'browse-url)
 (require 'emacspeak-outline)
@@ -71,18 +72,18 @@
 
 ;;}}}
 ;;{{{ advice interactive commands
-(loop for f in
-      '(muse-follow-name-at-point
-        muse-follow-name-at-point-other-window
-        muse-next-reference
-        muse-previous-reference)
-      do
-      (eval
-       `(defadvice   ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'large-movement)
-            (emacspeak-speak-line)))))
+(cl-loop for f in
+         '(muse-follow-name-at-point
+           muse-follow-name-at-point-other-window
+           muse-next-reference
+           muse-previous-reference)
+         do
+         (eval
+          `(defadvice   ,f (after emacspeak pre act comp)
+             "Provide auditory feedback."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'large-movement)
+               (emacspeak-speak-line)))))
 
 ;;}}}
 (provide 'emacspeak-muse)
