@@ -1,5 +1,5 @@
-;;; emacspeak-ocr.el --- ocr Front-end for emacspeak desktop
-;;; $Id: emacspeak-ocr.el 7378 2011-11-10 17:34:32Z tv.raman.tv $
+;;; emacspeak-ocr.el --- ocr Front-end for emacspeak desktop  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for OCR
 ;;; Keywords: Emacspeak, ocr
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -59,6 +59,7 @@
 
 ;;}}}
 ;;{{{ required modules
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Customization variables
@@ -167,30 +168,30 @@ will be placed."
 (defvar emacspeak-ocr-buffer-name "*ocr*"
   "Name of OCR working buffer.")
 
-(defsubst emacspeak-ocr-get-buffer ()
+(defun emacspeak-ocr-get-buffer ()
   "Return OCR working buffer."
   (get-buffer-create
    (format  "*%s-ocr*"
             (emacspeak-ocr-default-name))))
 
-(defsubst emacspeak-ocr-get-text-name ()
+(defun emacspeak-ocr-get-text-name ()
   "Return name of current text document."
-  (declare (special emacspeak-ocr-document-name))
+  (cl-declare (special emacspeak-ocr-document-name))
   (format "%s.text" emacspeak-ocr-document-name))
 
-(defsubst emacspeak-ocr-get-image-name (extension)
+(defun emacspeak-ocr-get-image-name (extension)
   "Return name of current image."
-  (declare (special emacspeak-ocr-document-name
-                    emacspeak-ocr-last-page-number))
+  (cl-declare (special emacspeak-ocr-document-name
+                       emacspeak-ocr-last-page-number))
   (format "%s-p%s%s"
           emacspeak-ocr-document-name
           (1+ emacspeak-ocr-last-page-number)
           extension))
 
-(defsubst emacspeak-ocr-get-page-name ()
+(defun emacspeak-ocr-get-page-name ()
   "Return name of current page."
-  (declare (special emacspeak-ocr-document-name
-                    emacspeak-ocr-current-page-number))
+  (cl-declare (special emacspeak-ocr-document-name
+                       emacspeak-ocr-current-page-number))
   (format "%s-p%s.txt"
           emacspeak-ocr-document-name
           emacspeak-ocr-current-page-number))
@@ -205,25 +206,25 @@ will be placed."
     emacspeak-ocr-last-page-number)
   "Mode line format for OCR buffer.")
 
-(defsubst emacspeak-ocr-get-mode-line-format ()
+(defun emacspeak-ocr-get-mode-line-format ()
   "Return string suitable for use as the mode line."
-  (declare (special major-mode
-                    emacspeak-ocr-current-page-number))
+  (cl-declare (special major-mode
+                       emacspeak-ocr-current-page-number))
   (format "%s Page-%s/%s %s"
           (buffer-name)
           emacspeak-ocr-current-page-number
           emacspeak-ocr-last-page-number
           major-mode))
 
-(defsubst emacspeak-ocr-update-mode-line()
+(defun emacspeak-ocr-update-mode-line()
   "Update mode line for OCR mode."
-  (declare (special mode-line-format))
+  (cl-declare (special mode-line-format))
   (setq mode-line-format
         (emacspeak-ocr-get-mode-line-format)))
 
 ;;}}}
 ;;{{{  emacspeak-ocr mode
-(declaim (special emacspeak-ocr-mode-map))
+(cl-declaim (special emacspeak-ocr-mode-map))
 
 (define-derived-mode emacspeak-ocr-mode text-mode 
   "Major mode for document scanning and  OCR.\n"
@@ -261,7 +262,7 @@ The Emacspeak OCR front-end is launched by command
 emacspeak-ocr bound to \\[emacspeak-ocr].  
 
 This command switches to a special buffer that has OCR
-commands bounds to single keystrokes-- see the ke-binding
+commands bounds to single keystrokes-- see the key-binding
 list at the end of this description.  Use Emacs online help
 facility to look up help on these commands.
 
@@ -309,11 +310,11 @@ See \\{emacspeak-ocr-mode-map}.
 (define-key emacspeak-ocr-mode-map "I"
   'emacspeak-ocr-set-scan-image-options)
 (define-key emacspeak-ocr-mode-map "C" 'emacspeak-ocr-set-compress-image-options)
-(loop for i from 1 to 9
-      do
-      (define-key emacspeak-ocr-mode-map
-        (format "%s" i)
-        'emacspeak-ocr-page))
+(cl-loop for i from 1 to 9
+         do
+         (define-key emacspeak-ocr-mode-map
+           (format "%s" i)
+           'emacspeak-ocr-page))
 
 ;;}}}
 ;;{{{ interactive commands
@@ -342,10 +343,10 @@ For detailed help, invoke command emacspeak-ocr bound to
 \\[emacspeak-ocr] to launch emacspeak-ocr-mode, and press
 `?' to display mode-specific help for emacspeak-ocr-mode."
   (interactive)
-  (declare (special emacspeak-ocr-working-directory
-                    emacspeak-ocr-document-name
-                    buffer-read-only))
-  (let  ((buffer (emacspeak-ocr-get-buffer )))
+  (cl-declare (special emacspeak-ocr-working-directory
+                       emacspeak-ocr-document-name
+                       buffer-read-only))
+  (let  ((buffer (emacspeak-ocr-get-buffer)))
     (save-excursion
       (set-buffer buffer)
       (emacspeak-ocr-mode)
@@ -370,8 +371,8 @@ Pick a short but meaningful name."
   (interactive
    (list
     (read-from-minibuffer "Document name: ")))
-  (declare (special emacspeak-ocr-document-name
-                    mode-line-format))
+  (cl-declare (special emacspeak-ocr-document-name
+                       mode-line-format))
   (setq emacspeak-ocr-document-name name)
   (rename-buffer
    (format "*%s-ocr*" name)
@@ -383,15 +384,15 @@ Pick a short but meaningful name."
 (defun emacspeak-ocr-scan-image ()
   "Acquire page image."
   (interactive)
-  (declare (special emacspeak-speak-messages
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-image-extension
-                    emacspeak-ocr-keep-uncompressed-image
-                    emacspeak-ocr-scan-image
-                    emacspeak-ocr-scan-image-options
-                    emacspeak-ocr-compress-image
-                    emacspeak-ocr-compress-image-options
-                    emacspeak-ocr-document-name))
+  (cl-declare (special emacspeak-speak-messages
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-image-extension
+                       emacspeak-ocr-keep-uncompressed-image
+                       emacspeak-ocr-scan-image
+                       emacspeak-ocr-scan-image-options
+                       emacspeak-ocr-compress-image
+                       emacspeak-ocr-compress-image-options
+                       emacspeak-ocr-document-name))
   (let ((image-name (emacspeak-ocr-get-image-name
                      emacspeak-ocr-image-extension)))
     (let ((emacspeak-speak-messages nil))
@@ -413,7 +414,7 @@ Pick a short but meaningful name."
         (when emacspeak-ocr-keep-uncompressed-image
           (format "rm -f temp%s"
                   emacspeak-ocr-image-extension))))
-      (when (interactive-p)
+      (when (ems-interactive-p)
         (setq emacspeak-ocr-last-page-number
               (1+ emacspeak-ocr-last-page-number)))
       (message "Acquired  image to file %s"
@@ -424,15 +425,15 @@ Pick a short but meaningful name."
   "Scan in a photograph.
 The scanned image is converted to JPEG."
   (interactive "P")
-  (declare (special emacspeak-speak-messages
-                    emacspeak-ocr-jpeg-metadata-writer
-                    emacspeak-ocr-photo-compress-options
-                    emacspeak-ocr-scan-photo-options
-                    emacspeak-ocr-keep-uncompressed-image
-                    emacspeak-ocr-scan-image
-                    emacspeak-ocr-compress-photo
-                    emacspeak-ocr-image-extension
-                    emacspeak-ocr-document-name))
+  (cl-declare (special emacspeak-speak-messages
+                       emacspeak-ocr-jpeg-metadata-writer
+                       emacspeak-ocr-photo-compress-options
+                       emacspeak-ocr-scan-photo-options
+                       emacspeak-ocr-keep-uncompressed-image
+                       emacspeak-ocr-scan-image
+                       emacspeak-ocr-compress-photo
+                       emacspeak-ocr-image-extension
+                       emacspeak-ocr-document-name))
   (let (
         (jpg (emacspeak-ocr-get-image-name ".jpg"))
         (pnm (emacspeak-ocr-get-image-name ".pnm")))
@@ -450,7 +451,7 @@ The scanned image is converted to JPEG."
                   pnm)
         (format "rm -f temp.pnm"))))
     (when (and metadata
-               (interactive-p))
+               (ems-interactive-p))
       (setq metadata
             (read-from-minibuffer "Enter picture description: "))
       (let ((tempfile (format "temp%s.jpg" (gensym))))
@@ -483,8 +484,8 @@ The scanned image is converted to JPEG."
   "Writes out recognized text from current page
 to an appropriately named file."
   (interactive)
-  (declare (special emacspeak-ocr-current-page-number
-                    emacspeak-ocr-page-positions))
+  (cl-declare (special emacspeak-ocr-current-page-number
+                       emacspeak-ocr-page-positions))
   (cond
    ((= 0 emacspeak-ocr-current-page-number)
     (message "No pages in current document."))
@@ -499,11 +500,11 @@ to an appropriately named file."
        (emacspeak-ocr-get-page-name))
       (emacspeak-auditory-icon 'save-object))))
 
-(defun emacspeak-ocr-process-sentinel  (process state)
+(defun emacspeak-ocr-process-sentinel  (_process _state)
   "Alert user when OCR is complete."
-  (declare (special emacspeak-ocr-page-positions
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-current-page-number))
+  (cl-declare (special emacspeak-ocr-page-positions
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-current-page-number))
   (setq emacspeak-ocr-current-page-number
         emacspeak-ocr-last-page-number)
   (emacspeak-auditory-icon 'task-done)
@@ -518,12 +519,12 @@ to an appropriately named file."
 Prompts for image file if file corresponding to the expected
 `current page' is not found."
   (interactive)
-  (declare (special emacspeak-ocr-engine
-                    emacspeak-ocr-engine-options
-                    emacspeak-ocr-process
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-page-positions
-                    emacspeak-ocr-image-extension))
+  (cl-declare (special emacspeak-ocr-engine
+                       emacspeak-ocr-engine-options
+                       emacspeak-ocr-process
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-page-positions
+                       emacspeak-ocr-image-extension))
   (let ((inhibit-read-only t)
         (image-name
          (if (file-exists-p (emacspeak-ocr-get-image-name emacspeak-ocr-image-extension))
@@ -562,13 +563,13 @@ You need the imagemagik family of tools --- we use mogrify to transform the imag
 Prompts for image file if file corresponding to the expected
 `current page' is not found."
   (interactive)
-  (declare (special emacspeak-ocr-engine
-                    emacspeak-ocr-image-flipflop
-                    emacspeak-ocr-engine-options
-                    emacspeak-ocr-process
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-page-positions
-                    emacspeak-ocr-image-extension))
+  (cl-declare (special emacspeak-ocr-engine
+                       emacspeak-ocr-image-flipflop
+                       emacspeak-ocr-engine-options
+                       emacspeak-ocr-process
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-page-positions
+                       emacspeak-ocr-image-extension))
   (let ((inhibit-read-only t)
         (image-name
          (if (file-exists-p (emacspeak-ocr-get-image-name emacspeak-ocr-image-extension))
@@ -613,18 +614,18 @@ correctly by themselves."
 (defun emacspeak-ocr-open-working-directory ()
   "Launch dired on OCR working directory."
   (interactive)
-  (declare (special emacspeak-ocr-working-directory))
+  (cl-declare (special emacspeak-ocr-working-directory))
   (switch-to-buffer
    (dired-noselect emacspeak-ocr-working-directory))
   (emacspeak-auditory-icon 'open-object)
   (emacspeak-speak-mode-line))
 ;;;###autoload
-(defun emacspeak-ocr-forward-page (&optional count-ignored)
+(defun emacspeak-ocr-forward-page (&optional _count-ignored)
   "Like forward page, but tracks page number of current document."
   (interactive "p")
-  (declare (special emacspeak-ocr-page-positions
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-current-page-number))
+  (cl-declare (special emacspeak-ocr-page-positions
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-current-page-number))
   (cond
    ((= 0 emacspeak-ocr-current-page-number)
     (message "No pages in current document."))
@@ -642,11 +643,11 @@ correctly by themselves."
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'large-movement))))
 ;;;###autoload
-(defun emacspeak-ocr-backward-page (&optional count-ignored)
+(defun emacspeak-ocr-backward-page (&optional _count-ignored)
   "Like backward page, but tracks page number of current document."
   (interactive "p")
-  (declare (special emacspeak-ocr-page-positions
-                    emacspeak-ocr-current-page-number))
+  (cl-declare (special emacspeak-ocr-page-positions
+                       emacspeak-ocr-current-page-number))
   (cond
    ((= 0 emacspeak-ocr-current-page-number)
     (message "No pages in current document."))
@@ -665,9 +666,9 @@ correctly by themselves."
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'large-movement))))
 
-(defsubst emacspeak-ocr-goto-page (page)
+(defun emacspeak-ocr-goto-page (page)
   "Move to specified page."
-  (declare (special emacspeak-ocr-page-positions))
+  (cl-declare (special emacspeak-ocr-page-positions))
   (goto-char
    (aref emacspeak-ocr-page-positions page))
   (emacspeak-ocr-update-mode-line)
@@ -677,13 +678,13 @@ correctly by themselves."
 ;;;###autoload
 (defun emacspeak-ocr-page ()
   "Move to specified page."
-  (interactive )
+  (interactive)
   (when (= 0 emacspeak-ocr-last-page-number)
     (error "No pages in current document."))
   (let ((page
          (condition-case nil
-             (read (format "%c" last-input-event ))
-           (error nil ))))
+             (read (format "%c" last-input-event))
+           (error nil))))
     (or (numberp page)
         (setq page
               (read-minibuffer
@@ -698,9 +699,9 @@ correctly by themselves."
 (defun emacspeak-ocr-read-current-page ()
   "Speaks current page."
   (interactive)
-  (declare (special emacspeak-ocr-page-positions
-                    emacspeak-ocr-current-page-number
-                    emacspeak-ocr-last-page-number))
+  (cl-declare (special emacspeak-ocr-page-positions
+                       emacspeak-ocr-current-page-number
+                       emacspeak-ocr-last-page-number))
   (cond
    ((= emacspeak-ocr-current-page-number
        emacspeak-ocr-last-page-number)
@@ -724,7 +725,7 @@ Setting persists for current Emacs session."
     (read-from-minibuffer
      "Scan image settings:"
      emacspeak-ocr-scan-image-options)))
-  (declare (special emacspeak-ocr-scan-image-options))
+  (cl-declare (special emacspeak-ocr-scan-image-options))
   (setq emacspeak-ocr-scan-image-options setting))
 
 ;;;###autoload
@@ -737,7 +738,7 @@ Setting persists for current Emacs session."
     (read-from-minibuffer
      "Image compression settings: "
      emacspeak-ocr-compress-image-options)))
-  (declare (special emacspeak-ocr-compress-image-options))
+  (cl-declare (special emacspeak-ocr-compress-image-options))
   (setq emacspeak-ocr-compress-image-options setting))
 
 ;;}}}
