@@ -240,14 +240,16 @@ If electric mode is on, keystrokes invoke pianobar commands directly."
   (cl-declare (special pianobar-key-map))
   (cond
    ((and (stringp key)
-         (string= "'" key))
+         (or
+          (string= "\"" key)
+          (string= "'" key)))
     (emacspeak-pianobar-hide-or-show)
     (emacspeak-speak-mode-line))
    ((lookup-key pianobar-key-map key)
     (call-interactively (lookup-key pianobar-key-map key)))
    (t (pianobar-send-string  key))))
 
-;;;###autoload
+
 (defcustom emacspeak-pianobar-max-preset 10
   "Number of presets."
   :type 'number
