@@ -61,9 +61,7 @@
     (emacspeak-toggle-audio-indentation))
   (emacspeak-speak-mode-line))
 
-(defun emacspeak-sh-script-voice-lock-setup()
-  "Setup voice locking."
-  )
+
 
 (defadvice sh-indent-line (after emacspeak pre act comp)
   "Provide auditory feedback to indicate indentation."
