@@ -1,5 +1,5 @@
-;;; emacspeak-table.el --- Implements data model for table browsing
-;;; $Id: emacspeak-table.el 8276 2013-03-30 15:19:30Z tv.raman.tv $
+;;; emacspeak-table.el --- Implements data model for table browsing  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2018, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -39,11 +39,15 @@
 
 ;;{{{  Introduction
 
+;;; Commentary:
 ;;; Implements a module that provides a high level interface to
 ;;; tabulated information.
+;;; Code:
 
 ;;}}}
 ;;{{{ requires
+
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
 ;;}}}
@@ -53,11 +57,11 @@
 ;;; User of a table can:
 ;;; Ask to enumerate any row or column slice 
 ;;; While enumerating a slice ask for row/column header information.
-;;; While enumerating a slice, ask for information about neighbours:
+;;; While enumerating a slice, ask for information about neighbors:
 ;;;
 
-(defstruct (emacspeak-table
-            (:constructor cons-emacspeak-table))
+(cl-defstruct (emacspeak-table
+               (:constructor cons-emacspeak-table))
   row-header                            ;pointer to column  0
   column-header                         ;pointer to row 0
   current-row                           ;row containing point 
@@ -67,18 +71,16 @@
 ;;;###autoload
 (defun emacspeak-table-make-table (elements)
   "Construct a table object from elements."
-  (assert (vectorp elements) t
-          "Elements should be a vector of vectors" )
-  (let ((table (cons-emacspeak-table :elements elements ))
-        (row-h (make-vector (length  elements ) nil))
+  (cl-assert (vectorp elements) t "Elements should be a vector of vectors")
+  (let ((table (cons-emacspeak-table :elements elements))
+        (row-h (make-vector (length  elements) nil))
         (index 0))
-    (setf (emacspeak-table-column-header table ) (aref elements 0))
-    (loop for element across  elements 
-          do 
-          (assert (vectorp element) t
-                  "Row %s is not a vector" index)
-          (aset row-h index (aref element 0))
-          (incf index ))
+    (setf (emacspeak-table-column-header table) (aref elements 0)) ;first row
+    (cl-loop
+     for element across  elements do 
+     (cl-assert (vectorp element) t "Row %s is not a vector" index)
+     (aset row-h index (aref element 0)) ; build column 0
+     (cl-incf index))
     (setf (emacspeak-table-row-header table) row-h)
     (setf (emacspeak-table-current-row table) 0)
     (setf (emacspeak-table-current-column table) 0)
@@ -87,43 +89,40 @@
 ;;}}}
 ;;{{{ Accessors
 
-(defsubst emacspeak-table-this-element (table row column)
+(defun emacspeak-table-this-element (table row column)
   (let ((elements (emacspeak-table-elements  table)))
-    (aref
-     (aref elements row)
-     column)))
+    (aref (aref elements row) column)))
 
-(defsubst emacspeak-table-current-element (table)
+(defun emacspeak-table-current-element (table)
   (emacspeak-table-this-element table 
-                                (emacspeak-table-current-row table )
+                                (emacspeak-table-current-row table)
                                 (emacspeak-table-current-column table)))
 
-(defsubst emacspeak-table-this-row (table index)
+(defun emacspeak-table-this-row (table index)
   (aref  (emacspeak-table-elements table) index))
 
-(defsubst emacspeak-table-this-column (table column)
+(defun emacspeak-table-this-column (table column)
   (let*
-      ((elements (emacspeak-table-elements table ))
+      ((elements (emacspeak-table-elements table))
        (result (make-vector (length elements) nil))
        (index 0))
-    (loop for row across elements 
-          do
-          (aset result index
-                (aref row column))
-          (incf index))
+    (cl-loop
+     for row across elements do
+     (aset result index (aref row column))
+     (cl-incf index))
     result))
 
-(defsubst emacspeak-table-num-rows (table)
+(defun emacspeak-table-num-rows (table)
   (length (emacspeak-table-row-header table)))
 
-(defsubst emacspeak-table-num-columns (table)
+(defun emacspeak-table-num-columns (table)
   (length (emacspeak-table-column-header table)))
 
-(defsubst emacspeak-table-column-header-element (table column)
+(defun emacspeak-table-column-header-element (table column)
   (aref (emacspeak-table-column-header table) column))
 
-(defsubst emacspeak-table-row-header-element (table column)
-  (aref (emacspeak-table-row-header table) column))
+(defun emacspeak-table-row-header-element (table row)
+  (aref (emacspeak-table-row-header table) row))
 
 ;;}}}
 ;;{{{  enumerators
@@ -131,19 +130,21 @@
 (defun emacspeak-table-enumerate-rows (table callback &rest callback-args)
   "Enumerates the rows of a table.
 Calls callback once per row."
-  (loop for row across (emacspeak-table-elements table)
-        collect
-        (apply callback row callback-args )))
+  (cl-loop
+   for row across (emacspeak-table-elements table)
+   collect
+   (apply callback row callback-args)))
 
 (defun emacspeak-table-enumerate-columns (table callback &rest callback-args)
   "Enumerate columns of a table.
 Calls callback once per column."
-  (let ((elements (emacspeak-table-elements table )))
-    (loop for column   from 0 to (1- (length   elements))
-          collect
-          (apply callback
-                 (emacspeak-table-this-column table column)
-                 callback-args ))))
+  (let ((elements (emacspeak-table-elements table)))
+    (cl-loop
+     for column   from 0 to (1- (length   elements))
+     collect
+     (apply callback
+            (emacspeak-table-this-column table column)
+            callback-args))))
 
 ;;}}}
 ;;{{{ finders 
@@ -153,37 +154,41 @@ Calls callback once per column."
   "Look for next element matching pattern in  row."
   (or predicate
       (setq predicate 'equal))
-  (let ((next(%  (1+  (emacspeak-table-current-column table ))
+  (let ((next(%  (1+  (emacspeak-table-current-column table))
                  (emacspeak-table-num-columns  table)))
         (count   (emacspeak-table-num-columns table))
         (found nil))
-    (loop for   i from 0   to count
-          and column = next then (% (incf column) count)
-          if  (funcall predicate  pattern
-                       (emacspeak-table-this-element table  index column))
-          do (setq found t )
-          until found
-          finally return (and found column))))
+    (cl-loop
+     for   i from 0   to count
+     and column = next then (% (cl-incf column) count)
+     if
+     (funcall predicate  pattern
+              (emacspeak-table-this-element table  index column))
+     do
+     (setq found t)
+     until found
+     finally return (and found column))))
 
 (defun emacspeak-table-find-match-in-column (table index pattern
                                                    &optional predicate)
   "Look for element matching pattern in  column."
   (or predicate
       (setq predicate 'equal))
-  (let ((next(%  (1+  (emacspeak-table-current-row table ))
+  (let ((next(%  (1+  (emacspeak-table-current-row table))
                  (emacspeak-table-num-rows table)))
         (count   (emacspeak-table-num-rows table))
         (found nil))
-    (loop for   i from 0   to count
-          and row = next then (% (incf row) count)
-          if  (funcall predicate  pattern
-                       (emacspeak-table-this-element table  row index))
-          do (setq found t )
-          until found
-          finally return (and found row))))
+    (cl-loop for   i from 0   to count
+             and row = next then (% (cl-incf row) count)
+             if  (funcall predicate  pattern
+                          (emacspeak-table-this-element table  row index))
+             do (setq found t)
+             until found
+             finally return (and found row))))
 
 ;;}}}
 ;;{{{  Moving point:
+
 (defun emacspeak-table-goto-cell (table row column)
   "Move to a cell of the table"
   (let  ((row-count (emacspeak-table-num-rows table))
@@ -196,56 +201,56 @@ Calls callback once per column."
       (setf (emacspeak-table-current-row table) row)
       (setf (emacspeak-table-current-column table) column))
      (t (error "Current table has %s rows and %s columns"
-               row-count column-count )))))
+               row-count column-count)))))
 
 (defun emacspeak-table-move-up (table &optional count)
   "Move up in the table if possible."
-  (setq count (or count 1 ))
-  (let* ((current (emacspeak-table-current-row table ))
+  (setq count (or count 1))
+  (let* ((current (emacspeak-table-current-row table))
          (new (- current count)))
     (cond
      ((<= 0 new)
       (setf (emacspeak-table-current-row table) new))
      (t (message "Cannot move up by %s rows from row %s" count
-                 current )
+                 current)
         (emacspeak-auditory-icon 'warn-user)))))
 
 (defun emacspeak-table-move-down (table &optional count)
   "Move down in the table if possible."
-  (setq count (or count 1 ))
-  (let* ((current (emacspeak-table-current-row table ))
+  (setq count (or count 1))
+  (let* ((current (emacspeak-table-current-row table))
          (row-count (emacspeak-table-num-rows table))
          (new (+ current count)))
     (cond
      ((< new  row-count)
       (setf (emacspeak-table-current-row table) new))
      (t (message "Cannot move down by %s rows from row %s"
-                 count current )
+                 count current)
         (emacspeak-auditory-icon 'warn-user)))))
 
 (defun emacspeak-table-move-left (table &optional count)
   "Move left in the table if possible."
-  (setq count (or count 1 ))
-  (let* ((current (emacspeak-table-current-column table ))
+  (setq count (or count 1))
+  (let* ((current (emacspeak-table-current-column table))
          (new (- current count)))
     (cond
      ((<= 0 new)
       (setf (emacspeak-table-current-column table) new))
      (t (message "Cannot move left by %s columns from column %s"
-                 count current )
+                 count current)
         (emacspeak-auditory-icon 'warn-user)))))
 
 (defun emacspeak-table-move-right (table &optional count)
   "Move right in the table if possible."
-  (setq count (or count 1 ))
-  (let* ((current (emacspeak-table-current-column table ))
+  (setq count (or count 1))
+  (let* ((current (emacspeak-table-current-column table))
          (column-count (emacspeak-table-num-columns table))
          (new (+ current count)))
     (cond
      ((< new  column-count)
       (setf (emacspeak-table-current-column table) new))
      (t (message "Cannot move right by %s columns from column %s"
-                 count current )
+                 count current)
         (emacspeak-auditory-icon 'warn-user)))))
 
 ;;}}}
@@ -255,7 +260,7 @@ Calls callback once per column."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
