@@ -1,23 +1,23 @@
-;;; emacspeak-tar.el --- Speech enable Tar Mode -- Manipulate tar archives from Emacs
-;;; $Id: emacspeak-tar.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
-;;; $Author: tv.raman.tv $ 
+;;; emacspeak-tar.el --- Speech enable Tar Mode -- Manipulate tar archives from Emacs  -*- lexical-binding: t; -*-
+;;; $Id$
+;;; $Author: tv.raman.tv $
 ;;; Description: Auditory interface to tar mode
 ;;; Keywords: Emacspeak, Speak, Spoken Output, tar
-;;{{{  LCD Archive entry: 
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
 ;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
-;;;  $Revision: 4532 $ | 
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2011, T. V. Raman
-;;; All Rights Reserved. 
+;;; Copyright (c) 1995 -- 2018, T. V. Raman
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -40,13 +40,14 @@
 
 ;;{{{  Required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'tar-mode)
 ;;}}}
-;;{{{  Introduction 
-
+;;{{{  Introduction
+;;; Commentary:
 ;;;Auditory interface to tar mode
-
+;;; Code:
 ;;}}}
 ;;{{{ Helpers
 
@@ -58,58 +59,59 @@
    (t(save-excursion
        (end-of-line)
        (skip-syntax-backward "^ ")
-       (emacspeak-speak-line 1)))))
+       (emacspeak-speak-field
+        (point) (line-end-position))))))
 
 ;;}}}
 ;;{{{ Advice
 (defadvice tar-quit (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice tar-next-line (after emacspeak pre act comp)
   "Provide spoken feedback"
-  (when (interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-tar-speak-line)))
 
 (defadvice tar-previous-line (after emacspeak pre act comp)
   "Provide spoken feedback"
-  (when (interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-tar-speak-line)))
 
 (defadvice tar-flag-deleted (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-tar-speak-line)))
 
 (defadvice tar-unflag (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-tar-speak-line)))
 (defadvice tar-unflag-backwards (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-tar-speak-line)))
 
 (defadvice tar-extract (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice tar-extract-other-window (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice tar-view (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
@@ -129,10 +131,10 @@
       (message "No file on this line"))
      (t
       (setq mode
-            (tar-header-mode (tar-desc-tokens entry)))
+            (tar-header-mode  entry))
       (aset string 0       (if (zerop (logand 256 mode)) ?- ?r))
       (aset string   1 (if (zerop (logand 128 mode)) ?- ?w))
-      (aset string  2 (if (zerop (logand  64 mode)) ?- ?x)) 
+      (aset string  2 (if (zerop (logand  64 mode)) ?- ?x))
       (aset string  3 (if (zerop (logand  32 mode)) ?- ?r))
       (aset string  4 (if (zerop (logand  16 mode)) ?- ?w))
       (aset string  5 (if (zerop (logand   8 mode)) ?- ?x))
@@ -154,13 +156,12 @@
      ((null entry)
       (message "No file on this line"))
      (t (message  "File size %s "
-                  (tar-header-size (tar-desc-tokens
-                                    entry)))))))
+                  (tar-header-size entry))))))
 
 (defun emacspeak-tar-speak-file-date()
   "Speak date of file current entry "
   (interactive)
-  (declare (special emacspeak-speak-time-format-string))
+  (cl-declare (special emacspeak-speak-time-format-string))
   (unless (eq major-mode 'tar-mode)
     (error "This command should be called only in tar mode"))
   (let ((entry (tar-current-descriptor)))
@@ -170,27 +171,26 @@
      (t (message  "Modified on  %s "
                   (format-time-string
                    emacspeak-speak-time-format-string
-                   (tar-header-date
-                    (tar-desc-tokens entry))))))))
+                   (tar-header-date entry)))))))
 
 (defun emacspeak-tar-setup-keys ()
   "Setup emacspeak keys for tar mode"
-  (declare (special tar-mode-map))
-  (define-key tar-mode-map "z" 'emacspeak-tar-speak-file-size)       
+  (cl-declare (special tar-mode-map))
+  (define-key tar-mode-map "z" 'emacspeak-tar-speak-file-size)
   (define-key tar-mode-map "/" 'emacspeak-tar-speak-file-permissions)
   (define-key tar-mode-map "c" 'emacspeak-tar-speak-file-date)
   )
 
-(eval-when (load)
+(cl-eval-when (load)
   (emacspeak-tar-setup-keys))
 
 ;;}}}
 (provide 'emacspeak-tar)
-;;{{{ end of file 
+;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
 ;;; byte-compile-dynamic: t
-;;; end: 
+;;; end:
 
 ;;}}}
