@@ -1,5 +1,5 @@
-;;; emacspeak-tcl.el --- Speech enable TCL development environment
-;;; $Id: emacspeak-tcl.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
+;;; emacspeak-tcl.el --- Speech enable TCL development environment  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for tcl-mode
 ;;; Keywords:emacspeak, audio interface to emacs tcl
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2018, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -38,11 +38,12 @@
 ;;}}}
 
 ;;{{{  Introduction:
-
+;;; Commentary:
 ;;; Provide additional advice to tcl-mode 
-
+;;; Code:
 ;;}}}
 ;;{{{ requires
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
 ;;}}}
@@ -69,10 +70,10 @@ This exists because some people (eg, me) use \"defvar\" et al. ")
 (defvar tcl-keyword-list
   '("if" "then" "else" "elseif" "for" "foreach" "break" "continue" "while"
     "set" "eval" "case" "in" "switch" "default" "exit" "error" "proc" "return"
-    "uplevel" "loop" "for_array_keys" "for_recursive_glob" "for_file"
+    "uplevel" "cl-loop" "for_array_keys" "for_recursive_glob" "for_file"
     "unwind_protect" 
     ;; itcl
-    "method" "itcl_class" )
+    "method" "itcl_class")
   "List of Tcl keywords.  Used only for highlighting.
 Default list includes some TclX keywords. ")
 
@@ -96,8 +97,8 @@ Default list includes some TclX keywords. ")
     ;; Loop handling is not perfect, because the third argument can be
     ;; either a command or an expr, and there is no real way to look
     ;; forward.
-    ("loop" nil tcl-expr tcl-expr tcl-commands)
-    ("loop" nil tcl-expr tcl-commands)
+    ("cl-loop" nil tcl-expr tcl-expr tcl-commands)
+    ("cl-loop" nil tcl-expr tcl-commands)
     )
   "Alist that controls indentation.
 \(Actually, this really only controls what happens on continuation lines).
@@ -109,54 +110,48 @@ Each type entry describes a sexp after the keyword, and can be one of:
 * a string, which must exactly match the string at the corresponding
   position for a match to be made.
 
-For example, the entry for the \"loop\" command is:
+For example, the entry for the \"cl-loop\" command is:
 
-   (\"loop\" nil tcl-expr tcl-commands)
+   (\"cl-loop\" nil tcl-expr tcl-commands)
 
-This means that the \"loop\" command has three arguments.  The first
+This means that the \"cl-loop\" command has three arguments.  The first
 argument is ignored (for indentation purposes).  The second argument
 is a Tcl expression, and the last argument is Tcl commands.")
 
 ;;}}}
 ;;{{{  Advice electric insertion to talk:
-(unless (and (boundp 'post-self-insert-hook)
-             post-self-insert-hook
-             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
-  (defadvice tcl-electric-hash (after emacspeak pre act comp )
-    "Speak what you inserted."
-    (when (ems-interactive-p )
-      (emacspeak-speak-this-char last-input-event))))
-(unless (and (boundp 'post-self-insert-hook)
-             post-self-insert-hook
-             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
-  (defadvice tcl-electric-char (after emacspeak pre act comp )
-    "Speak what you inserted."
-    (when (ems-interactive-p )
-      (emacspeak-speak-this-char last-input-event))))
-(unless (and (boundp 'post-self-insert-hook)
-             post-self-insert-hook
-             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
-  (defadvice tcl-electric-brace (after emacspeak pre act comp )
-    "Speak what you inserted."
-    (when (ems-interactive-p )
-      (emacspeak-speak-this-char last-input-event))))
+
+(defadvice tcl-electric-hash (after emacspeak pre act comp)
+  "Speak what you inserted."
+  (when (ems-interactive-p)
+    (emacspeak-speak-this-char last-input-event)))
+
+(defadvice tcl-electric-char (after emacspeak pre act comp)
+  "Speak what you inserted."
+  (when (ems-interactive-p)
+    (emacspeak-speak-this-char last-input-event)))
+
+(defadvice tcl-electric-brace (after emacspeak pre act comp)
+  "Speak what you inserted."
+  (when (ems-interactive-p)
+    (emacspeak-speak-this-char last-input-event)))
 
 ;;}}}
 ;;{{{  Actions in the tcl mode buffer:
 
 (defadvice switch-to-tcl (before emacspeak pre act comp)
   "Announce yourself."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (message "Switching to the Inferior TCL buffer")))
 
 (defadvice tcl-eval-region (after emacspeak  pre act comp)
   "Announce what you did."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (message "Evaluating contents of region")))
 
-(defadvice tcl-eval-defun (after emacspeak pre act comp )
+(defadvice tcl-eval-defun (after emacspeak pre act comp)
   "Announce what you did"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (let* ((start nil)
            (proc-line
             (save-excursion
@@ -164,42 +159,42 @@ is a Tcl expression, and the last argument is Tcl commands.")
               (setq start (point))
               (end-of-line)
               (buffer-substring start (point)))))
-      (message "Evaluated  %s" proc-line ))))
+      (message "Evaluated  %s" proc-line))))
 
 (defadvice tcl-help-on-word (after emacspeak pre act comp)
   "Speak  the help."
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'help)
-    (with-current-buffer "*Tcl help*"      (emacspeak-speak-buffer ))))
+    (with-current-buffer "*Tcl help*"      (emacspeak-speak-buffer))))
 
 ;;}}}
 ;;{{{  Program structure:
 
 (defadvice tcl-mark-defun (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (message "Marked procedure")))
 
 (defadvice tcl-beginning-of-defun (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-speak-line )))
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'paragraph)
+    (emacspeak-speak-line)))
 
 (defadvice tcl-end-of-defun (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'large-movement)))
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'paragraph)))
 
-(defadvice indent-tcl-exp (after emacspeak pre act )
+(defadvice indent-tcl-exp (after emacspeak pre act)
   "Produce an auditory icon"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'fill-object)))
 
 (defadvice tcl-indent-line (after emacspeak pre act)
   "Speak the line"
-  (when (ems-interactive-p )
+  (when (ems-interactive-p)
     (emacspeak-speak-line)))
 ;;}}}
 
@@ -208,7 +203,7 @@ is a Tcl expression, and the last argument is Tcl commands.")
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
