@@ -1,5 +1,5 @@
-;;; emacspeak-tdtd.el --- Speech enable  DTD authoring 
-;;; $Id: emacspeak-tdtd.el 7323 2011-10-26 00:50:39Z tv.raman.tv $
+;;; emacspeak-tdtd.el --- Speech enable  DTD authoring  -*- lexical-binding: t; -*- 
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable tdtd 
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,6 +40,7 @@
 
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
@@ -62,9 +63,9 @@
 
 (defun emacspeak-tdtd-voice-lock-setup()
   "Setup voice locking for tdtd mode."
-  (declare (special 
-            dtd-xml-flag 
-            dtd-decl-flag dtd-sys-decl-flag ))
+  (cl-declare (special 
+               dtd-xml-flag 
+               dtd-decl-flag dtd-sys-decl-flag))
   (cond
    (dtd-xml-flag)
    (dtd-decl-flag
