@@ -156,13 +156,14 @@
                        tetris-next-shape
                        tetris-n-rows emacspeak-tetris-filled-a-row))
   (dtk-speak
-   (format "%s %s at rotation  %s next is %s"
-           (if emacspeak-tetris-filled-a-row 
-               tetris-n-rows
-             " ")
-           (emacspeak-tetris-shape-name (1+ tetris-shape))
-           tetris-rot
-           (emacspeak-tetris-shape-name (1+ tetris-next-shape))))
+   (format
+    (format "%s %s at rotation  %s next is %s"
+            (if emacspeak-tetris-filled-a-row 
+                tetris-n-rows
+              " ")
+            (emacspeak-tetris-shape-name (1+ tetris-shape))
+            tetris-rot
+            (emacspeak-tetris-shape-name (1+ tetris-next-shape)))))
   (if emacspeak-tetris-filled-a-row
       (setq  emacspeak-tetris-filled-a-row nil)))
 
@@ -339,10 +340,10 @@ concentration and the game is a good mental challenge. "
     (dtk-set-punctuations 'all)
     (emacspeak-tetris-define-pronunciations)
     (emacspeak-tetris-define-keys)
+    (emacspeak-auditory-icon 'open-object)
     (emacspeak-tetris-speak-current-shape)
     (goto-char (point-min))
-    (forward-line tetris-height)
-    (message "Welcome to tetris!")))
+    (forward-line tetris-height)))
 
 (defadvice tetris-start-game (after emacspeak pre act comp)
   "Provide auditory feedback"
@@ -376,26 +377,31 @@ concentration and the game is a good mental challenge. "
 (defadvice tetris-move-left-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-to-x-pos (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-left (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-bottom (after emacspeak pre act comp)
@@ -549,7 +555,8 @@ concentration and the game is a good mental challenge. "
   (interactive "p")
   (cl-declare (special tetris-pos-x))
   (or  x (setq x tetris-pos-x))
-  (dtk-speak (emacspeak-tetris-get-column-contents x)))
+  (when  (sit-for 0.5 'no-disp)
+    (dtk-speak (emacspeak-tetris-get-column-contents x))))
 
 ;;}}}
 ;;{{{ Mode hook:
