@@ -1,5 +1,5 @@
-;;; emacspeak-todo-mode.el --- speech-enable todo-mode
-;;; $Id: emacspeak-todo-mode.el 6708 2011-01-04 02:27:29Z tv.raman.tv $
+;;; emacspeak-todo-mode.el --- speech-enable todo-mode  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description: todo-mode  for maintaining todo lists 
 ;;; Keywords: Emacspeak, todo-mode 
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2011, T. V. Raman
+;;; Copyright (c) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,43 +40,48 @@
 
 ;;{{{  Required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ Introduction:
-
+;;; Commentary:
 ;;; todo-mode (part of Emacs 21) provides todo-lists that can be
 ;;; integrated with the Emacs calendar.
-;;; This module speech-enables tood-mode
-
+;;; This module speech-enables todo-mode
+;;; Code:
 ;;}}}
 ;;{{{  Advice interactive commands:
 
 (defvar emacspeak-todo-mode-navigation-commands
   '(todo-forward-item
     todo-backward-item
+    todo-next-item
+    todo-previous-item
     todo-forward-category
     todo-backward-category
+    todo-next-category
+    todo-previous-category
     todo-jump-to-category
     )
   "Todo mode navigation commands to speech enable.")
 
-(loop for f in emacspeak-todo-mode-navigation-commands
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'select-object)
-            (emacspeak-speak-line)))))
+(cl-loop for f in emacspeak-todo-mode-navigation-commands
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Provide auditory feedback."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'select-object)
+               (emacspeak-speak-line)))))
 
 (defadvice todo-save (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)))
 
 (defadvice todo-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
