@@ -1,5 +1,5 @@
-;;; emacspeak-wdired.el --- Speech-enable wdired
-;;; $Id: emacspeak-wdired.el 7378 2011-11-10 17:34:32Z tv.raman.tv $
+;;; emacspeak-wdired.el --- Speech-enable wdired  -*- lexical-binding: t; -*-
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech-enable WDIRED
 ;;; Keywords: Emacspeak, Multimedia
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995--2004, 2011 T. V. Raman <raman@cs.cornell.edu>
+;;;Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -46,55 +46,56 @@
 ;;}}}
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'emacspeak-dired)
 
 ;;}}}
 ;;{{{ Advice interactive commands.
 
-(loop for c in
-      '(wdired-next-line wdired-previous-line)
-      do
-      (eval
-       `(defadvice ,c (after emacspeak pre act comp)
-          "Provide spoken feedback."
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'select-object)
-            (emacspeak-dired-speak-line)))))
+(cl-loop for c in
+         '(wdired-next-line wdired-previous-line)
+         do
+         (eval
+          `(defadvice ,c (after emacspeak pre act comp)
+             "Provide spoken feedback."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'select-object)
+               (emacspeak-dired-speak-line)))))
 
 (defadvice wdired-upcase-word (after emacspeak pre act comp)
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (tts-with-punctuations 'some
                            (dtk-speak "upper cased file name. "))))
 (defadvice wdired-capitalize-word (after emacspeak pre act comp)
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (tts-with-punctuations 'some
                            (dtk-speak "Capitalized file name. "))))
 (defadvice wdired-downcase-word (after emacspeak pre act comp)
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (tts-with-punctuations 'some
                            (dtk-speak "Down cased file
   name. "))))
 
 (defadvice wdired-toggle-bit (after emacspeak pre act comp)
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)
     (dtk-speak "Toggled permission bit.")))
 
 (defadvice wdired-abort-changes (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (tts-with-punctuations 'some
                            (dtk-speak "Cancelling  changes. "))))
 
 (defadvice wdired-finish-edit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)
     (tts-with-punctuations 'some
                            (dtk-speak "Committed changes. "))))
@@ -102,7 +103,7 @@
 (defadvice wdired-change-to-wdired-mode (after emacspeak pre act
                                                comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (tts-with-punctuations 'some
                            (dtk-speak "Entering writeable dir ed mode. "))))
