@@ -1,5 +1,5 @@
-;;; emacspeak-windmove.el --- speech-enable windmove 
-;;; $Id: emacspeak-windmove.el 7378 2011-11-10 17:34:32Z tv.raman.tv $
+;;; emacspeak-windmove.el --- speech-enable windmove  -*- lexical-binding: t; -*- 
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for WINDMOVE
 ;;; Keywords: Emacspeak, windmove
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -51,23 +51,23 @@
 ;;{{{ required modules
 
 ;;; Code:
-
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ advice window navigation
 
-(loop for f in
-      (list 'windmove-left
-            'windmove-right
-            'windmove-up
-            'windmove-down)
-      do
-      (eval
-       `(defadvice  ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (interactive-p)
-            (emacspeak-auditory-icon 'select-object)
-            (emacspeak-speak-mode-line)))))
+(cl-loop
+ for f in
+ '(windmove-left windmove-right
+                 windmove-up windmove-down)
+ do
+ (eval
+  `(defadvice  ,f (after emacspeak pre act comp)
+     "Provide auditory feedback."
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon select-object)
+       (emacspeak-speak-mode-line)))))
 
 ;;}}}
 
