@@ -1,5 +1,4 @@
-;;; plain-voices.el --- Define various device independent voices in terms of Plain codes.
-;;; $Id: plain-voices.el 6959 2011-04-01 15:39:52Z tv.raman.tv $
+;;; plain-voices.el --- Define various device independent voices in terms of Plain codes  -*- lexical-binding: t; -*-
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Module to set up Plain voices and personalities
 ;;; Keywords: Voice, Personality, Plain
@@ -15,7 +14,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2018, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -48,12 +47,14 @@
 ;;{{{ required modules
 
 ;;; Code:
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'acss-structure)
+(require 'tts)
 
 ;;}}}
-;;{{{  Top-level TTS  switcher
+;;;{{{  Top-level TTS  switcher
 
 ;;;### autoload
 (defun plain ()
@@ -69,10 +70,10 @@
 
 ;;; From dtk-speak.el:
 
-(defvar tts-default-speech-rate )
+(defvar tts-default-speech-rate)
 (defvar plain-default-speech-rate 75)
-(defvar dtk-speech-rate-step )
-(defvar dtk-speech-rate-base )
+(defvar dtk-speech-rate-step)
+(defvar dtk-speech-rate-base)
 
 ;;}}}
 ;;{{{  voice table
@@ -84,26 +85,26 @@
   "Association between symbols and strings to set Plain voices.
 The string can set any  parameter.")
 
-(defsubst plain-define-voice (name command-string)
+(defun plain-define-voice (name command-string)
   "Define a Plain voice named NAME.
 This voice will be set   by sending the string
 COMMAND-STRING to the TTS server."
-  (declare (special plain-voice-table ))
+  (cl-declare (special plain-voice-table))
   (puthash  name command-string  plain-voice-table))
 
-(defsubst plain-get-voice-command (name)
+(defun plain-get-voice-command (name)
   "Retrieve command string for  voice NAME."
-  (declare (special plain-voice-table ))
+  (cl-declare (special plain-voice-table))
   (cond
    ((listp name)
     (mapconcat #'plain-get-voice-command name " "))
    (t (or  (gethash name plain-voice-table)
            plain-default-voice-string))))
 
-(defsubst plain-voice-defined-p (name)
+(defun plain-voice-defined-p (name)
   "Check if there is a voice named NAME defined."
-  (declare (special plain-voice-table ))
-  (gethash name plain-voice-table ))
+  (cl-declare (special plain-voice-table))
+  (gethash name plain-voice-table))
 
 ;;}}}
 ;;{{{ voice definitions
@@ -134,19 +135,19 @@ COMMAND-STRING to the TTS server."
 (defvar plain-family-table nil
   "Association list of Plain voice names and control codes.")
 
-(defsubst plain-set-family-code (name code)
+(defun plain-set-family-code (name code)
   "Set control code for voice family NAME  to CODE."
-  (declare (special plain-family-table))
+  (cl-declare (special plain-family-table))
   (when (stringp name) (setq name (intern name)))
   (setq plain-family-table
-        (cons (list name code )
+        (cons (list name code)
               plain-family-table)))
 
-(defsubst plain-get-family-code (name)
+(defun plain-get-family-code (name)
   "Get control code for voice family NAME."
-  (declare (special plain-family-table ))
+  (cl-declare (special plain-family-table))
   (when (stringp name)
-    (setq name (intern name )))
+    (setq name (intern name)))
   (or (cadr (assq  name plain-family-table))
       ""))
 
@@ -168,17 +169,17 @@ COMMAND-STRING to the TTS server."
 Keys are symbols of the form <FamilyName-Dimension>.
 Values are vectors holding the control codes for the 10 settings.")
 
-(defsubst plain-css-set-code-table (family dimension table)
+(defun plain-css-set-code-table (family dimension table)
   "Set up voice FAMILY.
 Argument DIMENSION is the dimension being set,
 and TABLE gives the values along that dimension."
-  (declare (special plain-css-code-tables))
+  (cl-declare (special plain-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
-    (puthash  key table plain-css-code-tables )))
+    (puthash  key table plain-css-code-tables)))
 
-(defsubst plain-css-get-code-table (family dimension)
+(defun plain-css-get-code-table (family dimension)
   "Retrieve table of values for specified FAMILY and DIMENSION."
-  (declare (special plain-css-code-tables))
+  (cl-declare (special plain-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
     (gethash key plain-css-code-tables)))
 
@@ -205,7 +206,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ;no-op -- change to taste
             )))
    '(
@@ -213,14 +214,14 @@ and TABLE gives the values along that dimension."
      (1 101 112)
      (2 108 109)
      (3 112 106)
-     (4 118 103 )
+     (4 118 103)
      (5 122  100)
      (6 128 98)
      (7 134 96)
      (8 140 94)
      (9 147 91)
      ))
-  (plain-css-set-code-table 'paul 'average-pitch table ))
+  (plain-css-set-code-table 'paul 'average-pitch table))
 
 ;;}}}
 ;;{{{  harry average pitch
@@ -231,7 +232,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ; no-op --- change to taste
             )))
    '(
@@ -239,14 +240,14 @@ and TABLE gives the values along that dimension."
      (1 59 123)
      (2 68 121)
      (3 77 120)
-     (4 83  118 )
+     (4 83  118)
      (5 89 115)
      (6 95 112)
      (7 110 105)
      (8 125 100)
      (9 140 95)
      ))
-  (plain-css-set-code-table 'harry 'average-pitch table ))
+  (plain-css-set-code-table 'harry 'average-pitch table))
 
 ;;}}}
 ;;{{{  betty average pitch
@@ -256,7 +257,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format ""); no-op --- change to taste
             )))
    '(
@@ -264,18 +265,18 @@ and TABLE gives the values along that dimension."
      (1 170 112)
      (2 181 109)
      (3 192 106)
-     (4 200 103 )
+     (4 200 103)
      (5 208  100)
      (6 219 98)
      (7 225  96)
      (8 240 94)
      (9 260  91)
      ))
-  (plain-css-set-code-table 'betty 'average-pitch table ))
+  (plain-css-set-code-table 'betty 'average-pitch table))
 
 ;;}}}
 
-(defsubst plain-get-average-pitch-code (value family)
+(defun plain-get-average-pitch-code (value family)
   "Get  AVERAGE-PITCH for specified VALUE and  FAMILY."
   (or family (setq family 'paul))
   (if value
@@ -299,7 +300,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format ""); no-op --- chagne to taste.
             )))
    '(
@@ -307,14 +308,14 @@ and TABLE gives the values along that dimension."
      (1 20 10)
      (2 40 20)
      (3 60 30)
-     (4 80 40 )
-     (5 100 50 )
+     (4 80 40)
+     (5 100 50)
      (6 137 60)
      (7 174 70)
      (8 211 80)
      (9 250 100)
      ))
-  (plain-css-set-code-table 'paul 'pitch-range table ))
+  (plain-css-set-code-table 'paul 'pitch-range table))
 
 ;;}}}
 ;;{{{  harry pitch range
@@ -324,7 +325,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format ""); no-op --- change to taste
             )))
    '(
@@ -332,14 +333,14 @@ and TABLE gives the values along that dimension."
      (1 16 20)
      (2 32 40)
      (3 48 60)
-     (4 64 80 )
-     (5 80 100 )
+     (4 64 80)
+     (5 80 100)
      (6 137 100)
      (7 174 100)
      (8 211 100)
      (9 250 100)
      ))
-  (plain-css-set-code-table 'harry 'pitch-range table ))
+  (plain-css-set-code-table 'harry 'pitch-range table))
 
 ;;}}}
 ;;{{{  betty pitch range
@@ -349,7 +350,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format ""); no-op --- change to taste
             )))
    '(
@@ -357,17 +358,17 @@ and TABLE gives the values along that dimension."
      (1 50 10)
      (2 80 20)
      (3 100 25)
-     (4 110 30 )
+     (4 110 30)
      (5 140 35)
      (6 165 57)
      (7 190 75)
      (8 220 87)
      (9 250 100)
      ))
-  (plain-css-set-code-table 'betty 'pitch-range table ))
+  (plain-css-set-code-table 'betty 'pitch-range table))
 
 ;;}}}
-(defsubst plain-get-pitch-range-code (value family)
+(defun plain-get-pitch-range-code (value family)
   "Get pitch-range code for specified VALUE and FAMILY."
   (or family (setq family 'paul))
   (if value
@@ -394,14 +395,14 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ; no-op --- edit to taste
             )))
    '(
      (0  0 0 0 0)
      (1 3 6  20 3)
      (2 6 12  40 6)
-     (3 9 18  60 9 )
+     (3 9 18  60 9)
      (4 12 24 80 14)
      (5 18 32  100 18)
      (6 34 50 100 20)
@@ -419,15 +420,15 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ; no-op --- change to taste
             )))
    '(
      (0  0 0 0 0)
-     (1 4 6 2 2 )
-     (2 8 12 4 4 )
-     (3 12 18 6 6 )
-     (4 16 24 8 8 )
+     (1 4 6 2 2)
+     (2 8 12 4 4)
+     (3 12 18 6 6)
+     (4 16 24 8 8)
      (5 20 30 10 9)
      (6 40  48 32 16)
      (7 60 66 54 22)
@@ -444,14 +445,14 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ; no-op --- change to taste.
             )))
    '(
      (0  1 1 0 0)
      (1 3 4 11 0)
      (2 5 8 22 0)
-     (3 8 12 33 0 )
+     (3 8 12 33 0)
      (4 11  16 44 0)
      (5 14 20 55 0)
      (6 35 40 65 10)
@@ -462,8 +463,8 @@ and TABLE gives the values along that dimension."
   (plain-css-set-code-table 'betty 'stress table))
 
 ;;}}}
-(defsubst plain-get-stress-code (value family)
-  (or family (setq family 'paul ))
+(defun plain-get-stress-code (value family)
+  (or family (setq family 'paul))
   (if value
       (aref (plain-css-get-code-table family 'stress)
             value)
@@ -481,17 +482,17 @@ and TABLE gives the values along that dimension."
   (mapcar
    (function
     (lambda (setting)
-      (aset table (first setting)
+      (aset table (cl-first setting)
             (format "") ; no-op --- change to taste
             )))
    '(
      (0 0 100)
      (1 14 80)
      (2 28 60)
-     (3 42 40 )
+     (3 42 40)
      (4 56 20)
-     (5 70  3 )
-     (6 60 24 )
+     (5 70  3)
+     (6 60 24)
      (7 70 16)
      (8 80 8 20)
      (9 100  0)
@@ -505,7 +506,7 @@ and TABLE gives the values along that dimension."
   (mapcar
    (function
     (lambda (setting)
-      (aset table (first setting)
+      (aset table (cl-first setting)
             (format "") ; no-op --- change to taste
             )))
    '(
@@ -515,7 +516,7 @@ and TABLE gives the values along that dimension."
      (3 90 9)
      (4 88 11)
      (5 86 12)
-     (6 60 24 )
+     (6 60 24)
      (7 40 44)
      (8 20 65)
      (9 0 70)
@@ -529,7 +530,7 @@ and TABLE gives the values along that dimension."
   (mapcar
    (function
     (lambda (setting)
-      (aset table (first setting)
+      (aset table (cl-first setting)
             (format "") ; no-op -- change to taste.
             )))
    '(
@@ -539,7 +540,7 @@ and TABLE gives the values along that dimension."
      (3 24  28)
      (4 32 10)
      (5 40 4)
-     (6 50 3 )
+     (6 50 3)
      (7 65 3)
      (8 80 8 2)
      (9 100  0)
@@ -548,7 +549,7 @@ and TABLE gives the values along that dimension."
 
 ;;}}}
 
-(defsubst plain-get-richness-code (value family)
+(defun plain-get-richness-code (value family)
   (or family (setq family 'paul))
   (if value
       (aref (plain-css-get-code-table family 'richness)
@@ -558,7 +559,7 @@ and TABLE gives the values along that dimension."
 ;;}}}
 ;;{{{  punctuations
 
-(defsubst plain-get-punctuations-code (value)
+(defun plain-get-punctuations-code (value)
   "Return string needed to set specified punctuations mode."
   (if value
       (format "") ; no-op --- change to taste
@@ -578,12 +579,12 @@ and TABLE gives the values along that dimension."
            (plain-get-punctuations-code (acss-punctuations style))
            (when (or (acss-average-pitch style)
                      (acss-pitch-range style)
-                     (acss-stress style )
+                     (acss-stress style)
                      (acss-richness style))
              (concat "  "
                      (plain-get-average-pitch-code (acss-average-pitch style) family)
                      (plain-get-pitch-range-code (acss-pitch-range style) family)
-                     (plain-get-stress-code (acss-stress style ) family)
+                     (plain-get-stress-code (acss-stress style) family)
                      (plain-get-richness-code (acss-richness style) family))))))
     (plain-define-voice name command)))
 
@@ -592,18 +593,18 @@ and TABLE gives the values along that dimension."
 
 (defun plain-list-voices ()
   "List defined voices."
-  (declare (special plain-voice-table))
-  (loop for k being the hash-keys of plain-voice-table
-        collect   k))
+  (cl-declare (special plain-voice-table))
+  (cl-loop for k being the hash-keys of plain-voice-table
+           collect   k))
 
 ;;}}}
 ;;{{{ configurater
 ;;;###autoload
 (defun plain-configure-tts ()
   "Configures TTS environment to use Plain family of synthesizers."
-  (declare (special  plain-default-speech-rate
-                     tts-default-speech-rate
-                     tts-default-voice))
+  (cl-declare (special  plain-default-speech-rate
+                        tts-default-speech-rate
+                        tts-default-voice))
   (setq tts-default-voice 'paul)
   (fset 'tts-list-voices 'plain-list-voices)
   (fset 'tts-voice-defined-p 'plain-voice-defined-p)
@@ -613,13 +614,30 @@ and TABLE gives the values along that dimension."
   (setq tts-default-speech-rate plain-default-speech-rate)
   (set-default 'tts-default-speech-rate plain-default-speech-rate))
 
+;;}}}
+;;{{{ tts-env for Plain:
+;;;###autoload
+(defun plain-make-tts-env  ()
+  "Constructs a TTS environment for Plain."
+  (cl-declare (special plain-default-speech-rate))
+  (make-tts-env
+   :name :plain :default-voice 'paul
+   :default-speech-rate plain-default-speech-rate
+   :list-voices #'plain-list-voices
+   :acss-voice-defined-p #'plain-voice-defined-p
+   :get-acss-voice-command #'plain-get-voice-command
+   :define-voice-from-acss #'plain-define-voice-from-speech-style
+   :speech-rate-base 100 :speech-rate-step 10))
+
+(tts-env-set :plain  (plain-make-tts-env))
+
 ;;}}}
 (provide 'plain-voices)
 ;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
